# List of Changes for Multiphase Cases Repository by HZDR

## [Latest Release]

### Bugfix

- Fix rerunning of incomplete workflows
- Do not pass current working directory as argument to *_case rules
- Fix rerun of incomplete cases

### Post-Processing

- Plotting from probes for mean fields
- Automated decision tree plots from workflow runs

### Workflow

- Switch all shebang from /bin/sh to /bin/bash

---

## [Multiphase-Cases-Repository-10-s.2-hzdr.2-cases.1] - 2024-06-14

### Baseline

- Add case of Abe et al. (2018)
- Added bubble column cases of Sommer et al. (2023)
- Added 1994_Alajbegovic flotation cases
- Add remaining Zaehringer cases
- Added list of baseline keywords and a template for templated cases
- Add bubble column cases of Zaehringer (2020)
- Add bubble column cases of Mudde et al. (2009)
- Unify setups for bubble columns esp. regarding the outlet settings

### Bugfix

- Use correct RunFunctions in case-level scripts
- Fix workflow.yml

### Documentation

- Fix file endings for template post-processing setup
- Fix post-processing for etc/template/templateCase
- Improve etc/template/templatedCase with respect to post-processing
- Improve documentation on installing Snakemake as well as executing and cancelling a workflow on a cluster
- add documentation about goodness evaluation
- Add documentation on how to do model testing using centralized configuration files and OpenFOAM's include directive
- Generalize section on debugging a workflow
- Snakemake is now an optional dependency of the multiphasepy package
- Remove copyright header from createGraph scripts
- Introduce other copyright for other institutions
- Introduce new generalized source code header
- Moved recommended case structure to CONTRIBUTING.md
- correction of templates and urls

### Misc

- Collection of fixes
- Add model to control integral mass of selected phases
- consistent degassing BC for 2023 Sommer et al.
- Collection of minor issues
- Minor improvements in bubble column cases
- Adjust plot legend for Baseline cases (Baseline --> Reference)
- Fix default endTime value for templated cases 2005/2010_Lucas_et_al
- Minor fixes for templates
- Make templated cases use setCaseNumberOrDefault function
- Removed all but one entry from cspell-dict
- Fix Hibiki 32 crash

### MultiMorph Model

- Add ship hull air lubrication case including basic case study
- add reference data
- update plungingJetChansonEtAl2004 3D case

### OpenFOAM

- in #includeFunc directives rename remaining 'funcName' to 'name'

### Physical Modelling

- make drag coeff fromulation in ShiRzehak model a user parameter

### Post-Processing

- Integrate flotation cases into keyword list
- Notebook improvements for goodness evaluation
- Replace error by mre and pearson by pcc in plotGoodness.ipynb
- Replace fuzzy by mpyfuzzy in plotGoodness.ipynb
- Rename fuzzy tool to mpyfuzzy
- 1998 Liu case.yml --> case.yml.orig
- Change post-processing of all cases such that it can be tested in single timestep runs
- Introduce deltaG into plotGoodness script
- Switch to layerAverage functionObject for depth-averaging of profiles in 2019_Ziegenhein_and_Lucas cases
- Switch to layerAverage functionObject for cross-sectional averaging in 2020_Neumann_Kipping cases

### Workflow

- Add gas-solid-liquid bubble column by Sommer et al. (202x)
- Merged shell code for executing All<script>'s back into main Snakefile
- Place slurm output into separate log directory
- Automatically turn OpenFOAM shell scripts into bash scripts to avoid scenario that bash is not the default shell
- Templates for 2019 Ziegenhein and Lucas bubble column
- Move command for configuring case to run a single timestep to end of Allconfigure rule
- Can now be executed using Apptainer
- Move keywords to case.yml for keyword check
- Create template for 2008_Shawkat
- Optimise partitioning for Sommer et al. (2023)
- Created template for Liu (1998) cases
- Add references for velocity group cases of 2005_Lucas where possible
- Updated to be compatible with Snakemake's `--rerun-incomplete` option
- Enable category for changelog
- Re-instate optional fuzzy logic Post-Processing via multiphasePy module
- Allow submission of multi-node jobs
- Update of reference solutions
- Fix Allupdate script for 2016_Kim_et_al
- Several improvements
- Allow for multi-node jobs when submit to a cluster
- Fixed minor issues in templated cases
- Created template for Liu and Bankoff (1993) cases
- Created template for Hosokawa (2009) cases
- Created template for Kim et al. (2016) cases
- Add information on debugging a failed workflow
- Split generic rule for executing All<script>'s into individual rules to shorten error messages for simpler debugging
- Allow for more compact commands to execute the workflow
- Created template for Wang et al. (1987) cases
- Introduced Allupdate for all cases
- Several minor fixes for test loop
- Use specific pip version

---

## [Multiphase-Cases-Repository-10-s.2-hzdr.1-cases.1] - 2023-06-02

### Documentation

- Readme fix
- Rename to Multiphase Cases Repository by HZDR for OpenFOAM Foundation Software
- More straigtforward commands for release management

### OpenFOAM

- Sprint Cycle Upgrade 10-s.2

### Workflow

- Enable automatic update of reference solutions by executing the Allupdate rule

---

## [HZDR-Multiphase-Case-Collection-10-s.1-hzdr.3-cases.1] - 2023-03-21

### Baseline

- Fix plot script for 2005_Lucas_et_al/developing
- Re-add missing experimental data to 2001_Hibiki
- Remove problematic 2005_Lucas_et_al/59 case from workflow

### Bugfix

- postProcessing of rising bubble case according to Meller et al(2022)

### Documentation

- More descriptive merge request template for releases
- Improve description on how to execute the Snakemake workflow
- Modify command for running megalinter locally such that container is removed upon exit
- Update domain of GitLab instance
- Revise Markdown files according to common standard

### Misc

- Added 1987 Parthasarathy and Faeth to integration test
- Added particulate jet cases of Parthasarathy and Faeth (1987)
- Replaced prefix "HZDR" for libraries and exucutables by the more general "addon"
- Remove unnecessary pointSync entry from 1978_Deckwer_et_al/case16B/system/createPatchDict
- Separate multiple footnotes in README

### MultiMorph Model

- Rename OpenFOAM-Hybrid to MultiMorph Model

### OpenFOAM-Hybrid

- Add all hybrid cases to README file
- maintain Taylor-Green vortex
- Taylor-Green vortex setup simplified

### Physical Modelling

- Set interfacial models in 2003_Rampure cases directly rather than using includeEtc
- Updates to 2003_Rampure cases
- Adjusted fvModels for degassing bubble columns

### Workflow

- Allvalidate rule now considers plots for inclusion in a report if they carry the suffix "Validation"
- Remove unnecessary change of directory command in main Snakefile
- Improved error handling, CI/CD and documentation
- Remove left-over Snakefile.off from several cases
- Add description to validation report
- Activated automatic Snakefile formatting
- Redesigned implementation of the Snakemake workflow

---

## [HZDR-Multiphase-Case-Collection-10-s.1-hzdr.2-cases.2] - 2022-10-28

### Bugfix

- filter out isVersion from related identifiers
- fix entry for related identifiers
- Fix preview of README file in Rodare

---

## HZDR-Multiphase-Case-Collection-10-s.1-hzdr.2-cases.1 - 2022-10-20

### Baseline

- Update references
- Added cases simulating the multiphase turbulent jet experiments of Sun and Faeth (1985)
- Added setup for simulating the Deckwer et al. (1978) experiment studying CO2-interphase mass transfer in vertical cocurrent gas-liquid flow

### Documentation

- Contributing.md
- Automatically generate changelog based on git commits
- Introduce copyright headers and templates for all file types
- Enhanced description and installation instructions
- align keywords in Gitlab, Rodare, codemeta.json and HIFIS Software Spotlight

### Misc

- Update Ziegenhein for goodness evaluation
- Align experimental field names Liu 1998
- Liu 1998 README.md update
- Update reference data
- thermophysicalProperties.* -> physicalProperties for 1978_Deckwer_et_al

### OpenFOAM

- Sprint Cycle Upgrade 10-s.1

### OpenFOAM-Hybrid

- Add rising bubble case (Frederix case II), update and release some existing cases
- Add case setup MP-06 for distillation column tray
- update hybrid cases with new caseDicts

---
automatically generated with [git-chglog](https://github.com/git-chglog/git-chglog)
