# Simulation of Sun and Faeth (1986)

## Description

Case simulating a submerged single-phase and multi-phase (gas-liquid) turbulent
jet in a water tank is set-up with the Baseline models developed at HZDR. These
models are validated with the experiment from Sun and Faeth [^1][^2]. An
additional new turbulence model called as low Reynolds number $`k-\omega`$ SST
turbulence model by `kOmegaSSTLangtrySjolander`[^3], which is a modification of
the existing $`k-\omega`$ SST turbulence model, is also tested for the single
phase flow case.

## Technical Information

A submerged single phase as well as bubbly (gas-liquid) jet is injected inside a
rectangular cuboid water tank. The jet passes through a round nozzle of
$`5.08 mm`$  in diameter and oriented in vertically upward direction with a
uniform fixed value inlet velocity and gas fraction. A constant monodisperse
bubble size is used with $`d_B=1 \space mm`$. Air and water properties are
calculated at SATP. A total of 4 cases i.e. one single phase and three
multiphase cases are simulated.

The cases properties are listed in the following table:

|     Case     | $`U_G \space m/s`$ | $`vol_G \%`$ |
|:------------:|:------------------:|:------------:|
| singlePhase  |      $`1.61`$      |    $`0`$     |
| multiphase_1 |      $`1.65`$      |  $`0.024`$   |
| multiphase_2 |      $`1.68`$      |  $`0.048`$   |
| multiphase_3 |      $`1.77`$      |  $`0.091`$   |

## Pre-Processing

A cylindrical domain around the nozzle was considered for simulation and this
was simplified with the help of a wedge-shaped geometry with a wedge angle of
$`1.0`$ degree.

## Post-Processing

Validation data are available for the centreline streamwise velocity for gas and
liquid, and radial profiles of streamwise velocity for gas and liquid,
turbulent kinetic energy and gas fraction at different vertical positions.

## Additional Remarks

The following is prescriptions by Rzehak and Kriebitzsch [^4]  are used to
define the inlet boundary conditions. These are as follows:

- Relative velocity at the inlet is zero,
i.e. $`\alpha_G =J_G/(J_G+J_L)`$, and $`U_G=U_L=J_G+J_L`$
- $`I = 5\%`$ turbulence intensity is prescribed at the inlet
- Turbulent kinetic energy is calculated as:
$`k = \frac{3}{2} {(I\space u_L)}^2`$
- $`\omega`$ at the inlet is calculated using
$`\omega = \frac {k^{0.5}} {C_\mu \space L_t}`$ with $`L_t=0.1D`$ and
$`C_\mu=0.09`$
- Superficial velocities are termed as $`J_G`$ and $`J_L`$

## Literature

[^1]: Sun, T-Y., & Faeth,G.M. (1986). Structure of turbulent bubbly
      jets-I. International Journal. Int. J. Multiphase Flow Vol. 12,
      No. 1, pp. 99-114

[^2]: Sun, T-Y., & Faeth,G.M. (1986). Structure of turbulent bubbly
      jets-II. International Journal. Int. J. Multiphase Flow Vol. 12,
      No. 1, pp. 115-126

[^3]: Langtry, R., & Sjolander, S. (2002).Prediction of transition
      for attached and separated shear layers in turbomachinery.
      In 38th AIAA/ASME/SAE/ASEE Joint Propulsion Conference & Exhibit
      pp. 3641

[^4]: Rzehak, R., & Kriebitzsch, S. (2015).Multiphase CFD-simulation of bubbly
      pipe flow: A code comparison. Int. J. Multiphase Flow Vol. 68, pp. 135-152
