# Simulation of Wang et al. (1987)

## Description

This directory contains cases for the simulation of high Reynolds number
bubbly pipe flows with the HZDR Baseline model set. The data used for validation
originates from the experiment of Wang (1986)[^2], which provides information on
the local gas hold up, liquid velocity and turbulence structure. 12 combinations
of co-current upward flow, and 12 combinations of co-current downward flow are
available. Eight out of the in total 24 available combinations of gas and liquid
superficial velocities are currently considered in the weekly baseline workflow.
The available combinations are presented in Table 3-1 on page 64 of the
reference.

## Technical Information

The pipe has a diameter of 57.15mm and a length of 2m. A schematic of the
experiment is presented in Figure 2.1-1 of Wang (1986)[^2].

## Pre-Processing

The flow is assumed to be axisymmetric and the computational domain is a wedge
with an opening angle of 2.5 degree. Standard ambient temperature and a
temperature of 284.261K are used in all cases, albeit data on the pressure
gradient is available for each case from Table 3.1.4-1, page 121. The
thermophysical properties for air-water at the above mentioned conditions is
computed using HighProp Software. Both phases enter the domain through the inlet
 at its bottom end, where the
gas phase fraction is computed by

```math
\alpha_g=J_g/(J_g+J_l)
```

and the vertical velocity component for both phases by

```math
w_g=w_l=J_g+J_l\,,
```

i.e. there is no slip at the inlet. Note that adjusted values for the
superficial velocities were used to compute inlet conditions. At the inlet,
a turbulence intensity of 5percent is prescribed and the turbulent eddy
frequency is computed from the corresponding turbulent kinetic energy, assuming
a mixing length of 0.004m corresponding to 7 percent of the pipe diameter.
Information about the dispersed phase diameter was taken from Figure A.4.6-2
on page 357 (see Figure 3.1.3-7 on page 120 for the corresponding legend).
A constant density corresponding to the outlet pressure (SATP) is set for the
gas phase, i.e. the focus lies on the fully developed conditions at the end of
the computational domain.

## Post-Processing

Validation data is available for the gas phase fraction (Figure 3.1.4-1),
liquid phase velocity (Figure 3.1.7-8) and liquid phase turbulent fluctuations
(Figure 3.2-2 - 3.2-4). From the provided turbulent fluctuations, the turbulent
kinetic energy is computed by

```math
k_l = \frac{1}{2} (\sqrt{\bar{u^2}}^2 + \sqrt{\bar{v^2}}^2 + \sqrt{\bar{w^2}}^2)\,.
```

### Case Parameters

| J_L/J_V | 0.43 | 0.71 | 0.94 | 1.08 |
|:-------:|:----:|:----:|:----:|:----:|
|  0.10   |  LL  |  ML  |  HL  | XHL  |
|  0.27   |  LM  |  MM  |  HM  | XHM  |
|  0.40   |  LH  |  MH  |  HH  | XHH  |

The corresponding upward/downward flow cases are indicated with a "uw/dw".

## Additional Remarks

* adjusted velocities were extracted from the measured radial profiles to
  compute correct inlet conditions
* note that cases HL and XHL are transient and require time-averaging of results

## Literature

To get an overview, a look into Wang et al. (1987)[^1] suffices, but the actual
data is provided in the thesis from 1986[^2].

[^1]: Wang, S.K., Lee, S.J., Jones JR, O.C., Lahey JR, R.T. (1987).
      3-D turbulence structure and phase distribution measurements in bubbly
      two-phase flows. International J. Multiphase Flow, 13(3), 327-343.
[^2]: Wang, S.K. (1986).
      Three dimensional turbulence structure measurements in air/water two phase
      flow. PhD thesis, Rensselaer Polytechnic Inst., Troy, NY (USA).
