# Simulation of Liu and Bankoff (1993)

## Description

Cases for high Reynolds number bubbly pipe flows have been set-up with the
Baseline model set developed at HZDR. The cases are validated with the
experimental work of Liu (1989)[^3] and published in Liu and Bankoff (1993a)[^1]
and Liu and Bankoff (1993b)[^2].

## Technical Information

Experimental data stem from the PhD thesis of Liu (1989)[^3] and are stored in
the according validation directories together with a gnuplot script. The Allrun
script is used to run the simulation as well as to visualise the results.

The water used in the experiment was filtered and demineralised[^3].

The Sauter-mean diameter has been calculated as radius- and void fraction-
weighted average of the measured radial diameter distribution:

```math
    \overline{d}_b
  = \frac{\sum\limits_i \alpha_G(r_i)\ d_b(r_i)\ r_i}
    {\sum\limits_i \alpha_G(r_i)\ r_i}.
```

The reference data for turbulent kinetic energy k_L are calculated from axial
and lateral liquid velocity fluctuations, u_L' and v_L', respectively:

```math
    k_L
  = \frac{1}{2}\left({u_L^\prime}^2 + 2 {v_L^\prime}^2\right).
```

## Pre-Processing

To simplify the experimental setup for simulations, an axis-symmetric geometry
(2D-wedge of 2.5 deg.) for replicating the actual flow is simulated. Also, both
phases are made to enter from the same inlet with an inlet phase fraction.
No relative velocity between the phases is assumed at the inlet.

## Post-Processing

Line data are extracted via sampleFields functionObject.

### Case Parameters

| Case |  d_G   |  J_G  |  J_L  |   U   |
|:----:|:------:|:-----:|:-----:|:-----:|
| LB1  | 0.0023 | 0.027 | 1.087 | 1.114 |
| LB2  | 0.0032 | 0.112 | 1.087 | 1.199 |

## Additional Remarks

- Constant diameterModel and constant physical properties
- Zero velocity difference between phases at inlet, i.e. alpha=J_G/(J_G+J_L)),
  U_G=U_L=J_G+J_L
- 5% turbulence intensity is prescribed at the inlet
- Superficial velocities J_G and J_L are normal values
- Bubble diameters are calculated by averaging the bubble diameter profiles
- Experimental data are extracted from in Liu's PhD thesis

## Literature

[^1]: Liu, T. J., & Bankoff, S. G. (1993). Structure of air-water bubbly flow in a
      vertical pipe. I: Liquid mean velocity and turbulence measurements.
      J Heat Transfer, 36, 1049–1060.

[^2]: Liu, T. J., & Bankoff, S. G. (1993). Structure of air-water bubbly flow in a
      vertical pipe. II: Void fraction, bubble velocity and bubble size
      distribution. J Heat Transfer, 36, 1061–1972.

[^3]: Liu, T. J. (1989). Experimental investigation of turbulence structure in two-
      phase bubble flow. PhD Thesis, Northwestern University, Illinois, 251 pages.
