# Simulation of Liu (1998)

## Description

Cases for high Reynolds number bubbly pipe flows have been set-up with Baseline
Model developed at HZDR for closure of all interfacial forces involved in bubbly
flows. The same is being validated with the experimental work of
Liu (1998) [^1].

## Technical Information

Air and water flows in a circular pipe having a diameter D = 57.2 mm. The total
length of the flow section is H = 3.43 m. The material properties for air-water
at 26 °C temperature and at standard pressure is computed using HighProp
software.

In the experiment air was injected into the water flow through a porous
cylinder and sheared away by a high-speed nozzle water jet operated at
different velocities J_j. The cases contain the experimental data and a
baseline reference solution.

In order to run the simulation and plot results an Allrun script sitting in
every case folder can be executed.

## Pre-Processing

To simplify the experimental setup for simulations, an axis-symmetric geometry
(2D-wedge of 2.5 deg.) for replicating the actual flow is simulated. Also, both
phases are made to enter from the same inlet with an inlet phase fraction. No
relative velocity between the phases is assumed at the inlet.

## Post-Processing

See information inside cases.

### Case Parameters

| Case  | J_L | J_G | J_j |
|:-----:|:---:|:---:|:---:|
| L11A  | 0.5 | 0.1 | 6.0 |
| L21B  | 1.0 | 0.1 | 4.0 |
| L21C  | 1.0 | 0.1 | 2.0 |
| L22B^ | 1.0 | 0.2 | 4.0 |

^ in publications prior to 10/2022 falsely named L22A

## Additional Remarks

- Constant diameterModel and constant physical properties
- Zero velocity difference between phases at inlet, i.e. alpha=J_G/(J_G+J_L),
U_G=U_L=J_G+J_L
- 5% turbulence intensity is prescribed at the inlet
- Adjusting the gas volume flux at the inlet [^2]
- Adjusted values of gas volume flux i.e J_G reported in Rzehak et al., 2012
[^2].
  For the liquid volume flux i.e J_L, normal values are used
- Bubble diameters are calculated by averaging the bubble diameter profiles
- Time averaging is introduced due to transient effects (only `L21B` is known
to be affected though)

## Literature

[^1]: Liu, T.J. (1998). The role of bubble size on liquid phase turbulent
structure in two-phase bubbly flow. In Proceedings of the 3rd International
Conference on Multiphase Flow (ICMF’98), Lyon, France, 8–12 June 1998.

[^2]: Rzehak, R., Krepper, E. and Lifante, C., 2012. Comparative study of
wall-force models for the simulation of bubbly flows. Nuclear Engineering and
Design 253, 41-49.
