# Simulation of Pfleger (1999)

A bubble column case from the 1999_Pfleger[^1] paper has been set up and
compared to the experimental data. The Baseline model set developed at HZDR is
used for all the simulations.
The experiment was computed by several authors, each with a slightly different
setup: 2018_Askari[^2], 2008_Bannari[^3], 2004_Buwa[^5], 2002_Buwa[^4]
and 1999_Pfleger[^1].

## The experiment

### Technical information

The cross-section of the bubble column has a dimension of 0.2 x 0.05m, with the
height of the column not being specified. The fluid filling level is 0.45m. A
sparger is provided at the centre of the bottom plate. The sparger design is not
precisely described in the experimental paper. Standard ambient temperature and
pressure conditions apply.

### Data measured

Liquid velocity profiles were measured at a height of 0.37m.
Further validation data can be found in the literature below.

## The simulation setup

|        Dimension         | Sparger position |
|:------------------------:|:----------------:|
| 0.20 m x 0.05 m x 0.45 m |      centre      |

| Bubble diameters |     Gas volume flow rate | Gas mass flow rate |
|:----------------:|-------------------------:|:------------------:|
|     1 - 5 mm     | 48 l/h = 13.333e-6 m^3/s |   1.5786e-5 kg/s   |

### Pre-processing

The mesh resolution is 0.01x0.00$\overline{3}$x0.01m.

The turbulent initial values are:

```math
k_{water} = \frac{3}{2} (I\,U_{inlet})^2 \quad\text{and}\quad
\omega_{water} \approx 10^5 \,k_{water} \quad\text{(SI units assumed)} \\
\quad\text{resulting from}
\quad I=0.05 \quad\text{,}\quad
\omega = \frac{\rho}{\mu_{t}} \,k \quad\text{,}\quad
\frac{\mu_{t}}{\mu} = 10\\
```

Please note the remark on turbulence below.

The sparger is modelled using a mass source point in fvModels. The location of
the sparger is chosen at the centre of the bottom plate. The gas mass flow rate
is calculated from the given gas volume flow rate.
Due to the lack of sparger details given in the experimental paper, it is not
clear how to realise it optimally, but the results are probably not very
sensitive (Buwa et al., 2002[^4]).

#### Monodisperse case

Not considered here, but numerical results are available in the literature.

#### Polydisperse case

The bubble diameter range is captured by 9 size groups in 2 velocity groups.
One bubble size of each velocity group is selected to realise the gas injection
(sparger alpha ratio is 0.65/0.35).

Further work and relevant information can be found in Askari et al. (2018)[^2] and
Bannari et al. (2008)[^3].

## Post-Processing

Results are time-averaged from 50 to 300s.
After the simulation is completed, the data is extracted along line at y=0.37m
in mid-depth of the column and plots will be created.

The file `liqVel.dat` contains the measured average liquid velocity at y=0.37m
(Fig. 5 in Pfleger et al., 1999[^1]).

## Additional Remarks

- Turbulence: There seem to be alternative ways to prescribe k and omega.
One could, for example, prescribe k according to the experimental value
reported in 1999_Pfleger[^1] (Fig. 4). Omega may be computed using a mixing
length[^6]. Would be nice to know the best approach for bubble columns.

## Literature

[^1]: Pfleger, D., Gomes, S., Gilbert, N., & Wagner, H. G. (1999). Hydrodynamic
    simulations of laboratory scale bubble columns fundamental studies of the
    Eulerian–Eulerian modelling approach. Chemical Engineering Science, 54(21),
    5091-5099.

[^2]: Ehsan Askari, Pierre Proulx and Alberto Passalacqua 2018. Modelling of
    Bubbly Flow Using CFD-PBM Solver in OpenFOAM: Study of Local Population
    Balance Models and Extended Quadrature Method of Moments Applications.
    ChemEngineering 2018, 2, 8.

[^3]: Bannari, R., Kerdouss, F., Selma, B., Bannari, A., & Proulx, P. (2008).
    Three-dimensional mathematical modeling of dispersed two-phase flow using
    class method of population balance in bubble columns. Computers and
    Chemical Engineering, 32(12), 3224–3237.

[^4]: Buwa, V. V., & Ranade, V. V. (2002). Dynamics of gas-liquid flow in a
    rectangular bubble column: Experiments and single/multi-group CFD
    simulations. Chemical Engineering Science, 57(22–23), 4715–4736.

[^5]: Buwa, V. V., & Ranade, V. V. (2004). Characterization of dynamics of
    gas-liquid flows in rectangular bubble columns. AIChE Journal, 50(10),
    2394–2407.

[^6]: <https://cpp.openfoam.org/v8/classFoam_1_1turbulentMixingLengthFrequencyInletFvPatchScalarField.html#details>
