# Simulation of Deen (2000)

This case features the bubble column presented in Deen et al. (2000a)[^1].
The experimental results serve as reference in various journal publications,
e.g., Deen et al. (2000b)[^2], Deen et al. (2001)[^3], Holzinger (2016)[^4]
and Askari et al. (2018)[^5]. This case will simulate the bubble column with the
HZDR baseline model set and compare the simulation results to the experimental
data.

## The experiment

### Technical information

The bubble column has a dimension of 0.15x0.15x1m and contains distilled water
with 4g per litre NaCl to suppress coalescence. The bubble column is initially
filled with water up to a height of 0.45m[^1]. No information is provided about
pressure and temperature, hence Standard Ambient Temperature and Pressure
conditions are assumed. The bubbles diameter is 0.004m and the Eötvös number
is 2.2[^3]. The sparger is a square-shaped perforated plate in the middle of the
column with 49 holes (diameter of 1mm) set at a square pitch of 0.00625m. The
superficial gas velocity is 4.9e-3m/s[^3] (note, Deen et al., 2000a[^1] use
5e-3m/s).

### Data measured

Deen et al. (2000a)[^1] and Deen et al. (2001)[^3] provide various velocity
profiles measured with PIV and LDA in two measurement heights, 0.25m and 0.352m.
For the latter velocity profiles in different depths of the bubble column are
available, 1/2, 1/4, 1/8 and 1/16 of the column depth. For the first measurement
plane only velocity profiles at the centre of the column are available.

## The simulation setup

|        Dimension         | Sparger position |
|:------------------------:|:----------------:|
| 0.15 m x 0.15 m x 0.45 m |      centre      |

| Bubble diameter | Gas mass flow rate |
|:---------------:|:------------------:|
|      4 mm       |   1.305e-4 kg/s    |

### Pre-Processing

The mesh resolution is 0.01m in each direction and corresponds to the mesh used
by Deen et al. (2000b)[^2]

The sparger is modelled as a mass source point located in the centre of the
bottom-plate. The mass flow rate is determined from the gas superficial velocity
as $`1.305e-4 kg/s`$.

The surface tension coefficient is slightly adjusted to match the Eötvös number
given in the paper:

```math
Eö = \frac{g(\rho_{liq} - \rho_{gas})d_B^2}{\sigma} = 2.2 \\
\sigma = 0.071
```

The turbulent initial values are:

```math
k = \frac{3}{2} (I\,U)^2 \quad\mathrm{with}\quad I=0.05\\
\omega = \frac{\rho_{water}\,k}{\mu_{t,water}} = \frac{\rho_{water}\,k}{10 \mu_{water}}
\quad\mathrm{with}\quad \frac{\mu_{t,water}}{\mu_{water}} = 10\\
```

Note, that a value for k is required at the inlet to avoid a division by zero.

### Post-Processing

Results are time-averaged from 50 to 300s.
For sake of simplicity the validation data for this case are restricted to PIV
measured velocity profiles and the turbulent kinetic energy at height 0.25m[^3].
The abscissa of the graphs is normalised with the length of the bubble column,
according to the graphs presented in Deen et al. 2001[^3].

## Additional Remarks

None.

## Literature

[^1]: Deen, N.G., Hjertager, B.H., & Solberg, T. (2000a) Comparison of PIV and
      LDA Measurement Methods Applied to the Gas-Liquid Flow in a Bubble-Column.
      In: 10th Int. Symp. on Appl. of Laser Techniques to Fluid Mech., Lisbon,
      Portugal.

[^2]: Deen, N.G., Solberg, T., & Hjertager, B.H. (2000b). Numerical Simulation
      of the Gas-Liquid Flow in a Square Crosssectioned Bubble Column. In:
      14th Int. Congress of Chemical and Process Engineering, Praha, Czech
      Republic.

[^3]: Deen, N.G., Solberg, T., & Hjertager, B.H. (2001). Large eddy simulation
      of the gas-liquid flow in a square cross-sectioned bubble column. Chemical
      Engineering Science, 56, 6341–6349.

[^4]: Holzinger, G. (2016). Eulerian Two-Phase Simulation of the Floation
      Process with OpenFOAM. Ph.D. thesis, Johannes Kepler Universität Linz.

[^5]: Askari, E., Proulx, P. & Passalacqua, A. (2018). Modelling of Bubbly Flow
      Using CFD-PBM Solver in OpenFOAM: Study of Local Population Balance Models
      and Extended Quadrature Method of Moments Applications. ChemEngineering,
      2(1), 1-23.
