# Simulation of Hibiki (2001)

## Description

Cases for high Reynolds number bubbly pipe flows have been set-up with the
Baseline model set developed at HZDR. The models are validated with the
experimental work by Hibiki et al. (2001)[^1].

## Technical Information

Material properties correspond to 293.15 K at atmospheric pressure and were computed
with the HighProp software. The water in the experiment was purified[^1].

Bubble diameters are calculated by averaging measured bubble diameter profiles.

Experimental results were time-averaged and so are the computed results here.
Note that cases H31 and H32 show a transient behaviour indicating a
bubbly-to-slug flow transition.

The cases contain the experimental data to run the simulation and for
validating the results. All could be achieved by executing the Allrun
script to be found in every case folder. The script for creating plots
is inside the validation folder.

## Pre-Processing

To simplify the experimental setup for simulations, an axis-symmetric geometry
(2D-wedge of 1 deg.) for replicating the actual flow is simulated. Also, both
phases are made to enter from the same inlet with an inlet phase fraction, and
zero relative velocity between the phases is assumed.

## Post-Processing

See information inside cases.

## Additional Remarks

- Constant diameterModel and constant physical properties
- Zero velocity difference between phases at inlet,
  i.e. $`\alpha_G =J_G/(J_G+J_L)`$, and $`U_G=U_L=J_G+J_L`$
- 5% turbulence intensity is prescribed at the inlet
- Turbulent kinetic energy assumed anisotropic and extracted as:
  $`k= 0.5 \space (0.5u_z^{'2} + 0.5u_z^{'2} + u_z^{'2})`$
- $`u_z^{'}`$ is calculated using:
  $`u_z^{'}=I \space u_{z,max}`$,
  with $`u_{z,max}`$ being the max value from the liquid velocity profile
- $`\omega`$ at the inlet is calculated using
  $`\omega = \frac {k^{0.5}} {C_\mu^{0.25}\space L_t}`$ with $`L_t=0.07D`$ and
  $`C_\mu=0.09`$
- Superficial velocities $`J_G`$ and $`J_L`$ are normal values
- Case naming: the letter H stands for "Hibiki", the main author of the
  reference paper, the first number corresponds to the row number of Table 1 in
  the paper, and the second number corresponds to the column number of the same
  table.

## Literature

[^1]: Hibiki, T., Ishii, M., \& Xiao, Z. (2001). Axial interfacial area
      transport of vertical bubbly flows. International Journal of Heat and Mass
      Transfer, 44, 1869-1888.
