# Simulation of Lucas et al. (2005)

## Description

* Simulation of the co-current flow of air and water in a vertical pipe
  (d=51.2mm, l=3m) at 303.15K according to Lucas et al. (2005)[^2]
* Setups cover 86 different superficial velocity combinations, ranging from
  0.0025m/s to 0.543m/s for the air phase and 0.0405 to 4.047m/s for the water
  phase (MTLoop M01, see Prasser et al., 2003[^1])
* Superficial velocity combination (defined at T=293.15K and p=1013hPa) and
  initial/inlet bubble size distribution is determined by the case number[^5]
* Various templated setups [^6] are provided and briefly described below
* Users can select the case number to be simulated either directly in the
  `Allrun`[^7] script, or, in the context of a Snakemake workflow, provide a
  list of cases in the corresponding `yaml` file[^8]

## Technical Information

The water used in the experiment was deionised.

### General

* Axisymmetric setup ("wedge")
* Air is introduced into the domain uniformly through a mass source at the
  lowest measurement level, using the fvOption framework
* Developed single phase profiles for the water phase are ensured at the inlet
  by using mapped boundary conditions

### fullyDeveloped* setups

* Aims at validating models for interfacial exchange of momentum and
  bubble-induced turbulence
* Aims to answer the following research question: Provided the bubble size
  distribution could be frozen, what would the fully developed profiles look
  like? How well do the resulting profiles agree with the (nearly developed)
  experimentally determined ones at the highest measurement level?
* Fixed density, i.e. no dilatation
* Fixed size distribution based on the measurements at the highest level
* Flow develops over the domain length which has no physical meaning anymore
* fullyDevelopedVelocityGroups: Dispersed phase is split into 4 velocity groups,
  according to the characteristic turning points of the lift force coefficient
  model of Hessenkemper et al. (2021)[^9]

### homogeneous setup

* Single-cell setup
* Standalone solution of the population balance equation, using the volume
  averaged results from the fullyDeveloped (single velocity group) cases at
  the highest measurement level
* Useful for a quick evaluation of the validity of a coalescence and breakup
  model combination and for tuning coefficients

### developing* setups

* Study of the developing flow, including dilatation, coalescence and breakup
* Initial/inlet size distribution based on measurements at the lowest level
* developingVelocityGroups: Dispersed phase is split into 4 velocity groups,
  according to the characteristic turning points of the lift force coefficient
  model of Hessenkemper et al. (2021)[^9]

## Pre-Processing

Pre-processing is straight-forward, the user only needs to supply desired case
number.

## Post-Processing

See information inside cases.

## Additional Remarks

* Note that the experimental phase fraction profiles were corrected such that
  the corresponding superficial velocities
* match those prescribed by the experimental matrix (this is not the case in the
  raw experimental data)
* Note that the required physical time, i.e. the setting for the endTime, highly
  depends on the selected superficial
* velocity combination and is therefore computed using the `#calc` functionality
* Note report D. Lucas et al (2011)[^4]. This report is based on the data
  post-processed by Dirk, which are slightly different from the official m01
  data. This difference should be kept in mind, and it may have a substantial
  effect in some cases (107, for example, mentioned in verbal communication).
* More details can be found in Lehnigk (2021)[^3]

## Literature

[^1]: Prasser et al. (2003). Flow maps and models for transient two-phase flows.
      Final Report of Reactor Safety Research Project No.: 150 1215.
      Report - No.: FZR-379
[^2]: Lucas et al. (2005). Development of co-current air-water flow in a
      vertical pipe. International Journal of Multiphase Flow, 31, 1304-1328.
[^3]: Lehnigk (2021). A generalized population balance model for the simulation
      of polydisperse multiphase flows within the Euler-Euler framework.
      TU Dresden. Phd thesis.
[^4]: D. Lucas, Y. Liao, I. Markelov (2011). Air-water experiments in a vertical
      DN50-pipe. HZDR, Report.
[^5]: <https://codebase.helmholtz.cloud/fwdc/multiphase/cases/-/blob/main/baseline/2005_Lucas_et_al/constant/caseTable>
[^6]: <https://codebase.helmholtz.cloud/fwdc/multiphase/cases/-/tree/main/baseline/2005_Lucas_et_al/templates>
[^7]: <https://codebase.helmholtz.cloud/fwdc/multiphase/cases/-/blob/main/baseline/2005_Lucas_et_al/templates/developing/Allrun>
[^8]: <https://codebase.helmholtz.cloud/fwdc/multiphase/cases/-/blob/main/baseline.yaml>
[^9]: Hessenkemper et al. (2021). Lift force coefficient of ellipsoidal single
      bubbles in water. International Journal of Multiphase Flow, 138, 103587.
