# Simulation of Mudde et al. (2009)

## Description

This is a templated simulation setup for the bubble column experiment by
Mudde et al. (2009)[^1]. It corresponds to the cases mentioned in Table 2 of the
paper, which are here named "M1-M6". The simulation results are compared to the
available experimental data, which can be found in Fig. 8 and 10 in the paper.
The Baseline model set developed at HZDR is used.

## Technical Information

The bubble column is round and has a diameter of 0.15m. The ungassed liquid
height is 1.3m. No information is provided about the pressure and temperature,
hence Standard Ambient Temperature and Pressure conditions are assumed.

### Gas Inlet and Bubble Size

The gas is introduced at the bottom of the column through 559 needles arranged
in triangular pattern. The needles are divided into groups, in each of which
the gas flux is controlled. The number of active needles changes with the total
gas flux. This maintains the gas flux per needle in a narrow range and ensures
a narrow bubble size distribution across a wide range of total gas fluxes.
Thereby the uniform gas sparging is achieved by ensuring that the active needles
cover the entire column cross section.

Different contamination levels of tap water used in the experiment are
distinguished by the water age, which ranges between fresh (1 hour) and old
(3 weeks). The cases of interest (M1-M6) use water of several days old.
The bubble size is measured for the fresh and old water, but not for the water
of several days old, and not for the gas fluxes corresponding to cases M1-M3.
Since the gas flux per needle is maintained in a narrow range, it is assumed
that the cases M1-M3 produce similar bubble sizes as cases M4-M6. Therefore
the bubble diameter in all cases is assumed $4.25$ mm, which is the median-value
of the range determined by the fresh and old water ($3.5$ - $5$ mm) for the gas
fluxes corresponding to M4-M6.

### Case Parameters

| Name | $J_G$ [m/s] |
|:----:|:-----------:|
|  M1  |    0.015    |
|  M2  |    0.017    |
|  M3  |    0.025    |
|  M4  |    0.032    |
|  M5  |    0.039    |
|  M6  |    0.049    |

## Pre-Processing

* For simplification, an axi-symmetric geometry (2D-wedge of 1 degree) is used
* Degassing fvModel is used allowing the gas to leave the domain at the outlet
* The turbulent initial values are:

```math
k_{water} = \frac{3}{2} (I\,U_{inlet})^2 \quad\text{and}\quad
\omega_{water} \approx 10^5 \,k_{water} \\
\quad\text{resulting from}
\quad I=0.05 \quad\text{,}\quad
\omega_{water} = \frac{\rho_{water}}{\mu_{t}} \,k \quad\text{,}\quad
\frac{\mu_{t}}{\mu_{mol}} = 10 \quad\text{,}\quad U_{inlet}=0.02\\
\text{(SI units assumed)}\\
```

## Post-Processing

* Radial gas fraction profile at heights $z/H = 0.46$ and $= 0.96$
* Radial profile of axial liquid velocity at height $z/H = 0.46$

## Additional Remarks

* The mesh resolution corresponds to $\Delta x/d_B = 0.7$, and it was found that
a finer mesh leads to staggering, while a coarser mesh influences the solution

## Literature

[^1]: Mudde, R. F., Harteveld, W. K., and van den Akker, H. E. A., (2009).
      Uniform flow in bubble-columns. Industrial & Engineering Chemistry
      Research 48, 148-158.
