# Simulation of Akbar et al. (2012)

Two bubble column cases from the 2012_Akbar[^1] paper have been setup. For
reference CFX results [^2] and experimental data are available. The Baseline
model set developed at HZDR is used for all the simulations.

## The experiment

## Technical Information

The bubble column cross-section has a dimension of $`0.24\,m \times 0.072\,m`$
with the height o the column unknown. The initial filling level is $`0.7\,m`$.

The two cases are named after their respective superficial gas velocities.
Standard ambient temperature and pressure conditions apply.

## Data measured

Measured were the gas and liquid velocity profiles as well as the gas void
fraction profile at a height of 0.5m.

## The simulation setup

|        Dimension         | Sparger position |
|:------------------------:|:----------------:|
| 0.24 m x 0.072 m x 0.7 m |      centre      |

| Subcase | Bubble diameter | Gas mass flow rate |
|:-------:|----------------:|:------------------:|
|   A3    |           4.3mm |   6.138e-5 kg/s    |
|   A13   |       5.3-6.3mm |    2.66e-4 kg/s    |

### Case A3 (monodisperse)

Superficial gas velocity is $`0.003\,ms^{-1}`$, which corresponds to a mass
flow rate of $`6.138e-5 kg/s`$. The bubble size is modelled monodisperse with
an average diameter of $`4.3\,mm`$.

### Case A13 (fixed polydisperse)

Superficial gas velocity is $`0.013\,ms^{-1}`$, which corresponds to a mass
flow rate of $`2.66e-4 kg/s`$. The bubble size is modelled fixed polydisperse
with two velocity groups as proposed in 2015_Ziegenhein[^2]:

| Velocity group | Sauter mean diameter (mm) | Phase fraction |
|----------------|---------------------------|----------------|
| 1              | 5.3                       | 0.63           |
| 2              | 6.3                       | 0.37           |

## Pre-Processing

An equidistant grid with 0.004m in each direction is used.

The sparger is modelled with 24 mass source points[^2]. Please note that the
number of injection holes was different in the original work of 2012_Akbar[^1].

The turbulent initial values are:

```math
k = \frac{3}{2} (I\,U)^2 \quad\mathrm{with}\quad I=0.05\\
\omega = \frac{\rho_{water}\,k}{\mu_{t,water}} = \frac{\rho_{water}\,k}{10 \mu_{water}}
\quad\mathrm{with}\quad \frac{\mu_{t,water}}{\mu_{water}} = 10\\
```

## Post-Processing

Results are time-averaged from 50s to 300s (A3)/ 800s (A13).

For post-processing a horizontal line is compared to experimental data and CFX
data. Especially the $`0.013\,ms^{-1}`$ case needs quite a long time (approx.
700s) to generate stable mean values. The whole case is very sensitive to
changes in boundary conditions and numerical settings. Reducing the averaging
window or shifting it to earlier times can change results and has to be checked
carefully.

Note: In Ziegenhein et al. (2015) a convergence criteria was developed based on
the comparison of a window average and the overall average. The criteria
seems to be over-engineered as the same can be achieved by checking probes for
mean velocity and mean phase fraction. However, in case resolved Reynolds
stresses are required the averaging window has to be extended a lot, as second
order statistics require much more time to converge than first order (mean).

## Additional Remarks

Note that the vortex system showed to be very (!) sensitive to spatial
resolution. As a consequence, the velocity profiles may change considerably
in case of mesh refinement. This was observed with Case 3 and is not yet
fully understood.

Note, that the influence of the changes in faceMomentum (commit 87a7d4e) is not
tested in this case. Potentially, cell momentum, i.e. `faceMomentum false;`, is
required to achieve pleasant result or to achieve a numerically stable solution
in the first place.

## Literature

[^1]: Akbar, M. H. M., Hayashi, K., Hosokawa, S., & Tomiyama, A. (2012).
    Bubble tracking simulation of bubble-induced pseudoturbulence.
    Multiphase Science and Technology, 24, 197–222.

[^2]: Ziegenhein, T., Rzehak, R., & Lucas, D. (2015).
    Transient simulation for large scale flow in bubble columns.
    Chemical EngineeringScience, 122, 1–13.
