# Simulation of Ziegenhein and Lucas (2019)

Bubble column cases have been setup using the baseline model set developed at
HZDR. The model set is validated with the experimental data of Ziegenhein and
Lucas (2019) [^1] and Lucas and Ziegenhein (2019) [^2]. The cases selected here
are N90, N70 and N25.

## The experiment

### Technical information

A rectangular bubble column with a width of $`112.5 mm`$, a depth of $`50 mm`$
and a height of $`2000 mm`$ was used in the experiment. It was filled with
deionized water up to a height of $`1800 mm`$. The gas injection is controlled
in two groups (G1 with 4 needles of diameter 0.3mm and G2 with 2 needles of
diameter 0.6mm), making up a total of 6 needles, which are located at the column
bottom. The air volume flow rate was fixed to $`1.0 l/min`$ for all experiments.
Standard Ambient Temperature and Pressure conditions apply.

### Data measured

The upward liquid velocity, the gas void fraction and the volume density
function were measured. Velocities were measured in the centre of the bubble
column at the various measuring heights. Bubble sizes and the void fraction
were evaluated from pictures covering the entire width of the bubble column.

## The simulation setup

|         Dimension         | Sparger position |
|:-------------------------:|:----------------:|
| 0.1125 m x 0.05 m x 1.8 m |      centre      |

| Subcases | Bubble size  | (Sauter mean) Bubble diameter |
|:--------:|:------------:|:-----------------------------:|
|   N70    | monodisperse |            4.882mm            |
|   N90    | monodisperse |            5.183mm            |
|   N25    | polydisperse |         1.25 - 12.1mm         |
|          |     air1     |            3.815mm            |
|          |     air2     |            7.399mm            |

### Pre-Processing

An equidistant grid of 3.125mm size is used.

The gas is injected via 6 mass source points. The injector group G1 makes 4 mass
source points, and the injector group G2 makes 2 mass source points.

#### Case N70 (monodisperse)

The gas volume flow rate is split into $`0.7 l/min`$ from G1 (4 needles),
and $`0.3 l/min`$ from G2 (2 needles). This corresponds to a mass flow rate of
$`1.384e-5 kg/s`$ from G1, and $`5.92e-6 kg/s`$ from G2.

#### Case N90 (monodisperse)

The gas volume flow rate is split into $`0.9 l/min`$ from G1 (4 needles),
and $`0.1 l/min`$ from G2 (2 needles). This corresponds to a mass flow rate of
$`1.776e-5 kg/s`$ from G1, and $`1.966e-6 kg/s`$ from G2.

#### Case N25 (fixed polydisperse)

The gas volume flow rate is split into $`0.25 l/min`$ from G1 (4 needles),
and $`0.75 l/min`$ from G2 (2 needles). The gas flow from each injector group
is split into two velocity groups (1 and 2). The phase fraction of velocity
group 1 is $`0.307`$, while the phase fraction of velocity group 2 is $`0.693`$

| Injector group | Velocity group | Mass flow rate [kg/s] | Volume flow rate [l/min] x Phase fraction |
|----------------|----------------|-----------------------|-------------------------------------------|
| G1             | 1              | 1.5145e-6             | 0.25 x 0.307                              |
| G1             | 2              | 3.4188e-6             | 0.25 x 0.693                              |
| G2             | 1              | 4.5436e-6             | 0.75 x 0.307                              |
| G2             | 2              | 1.0256e-5             | 0.75 x 0.693                              |

### Post-Processing

Results are time-averaged starting from 40s up to 100s simulation time.
Liquid velocities are plotted using line plots in the bubble column centre.
The results for the gas velocity and void fraction are depth-averaged in order
to mimic the experimental measuring technique. Ten cell zones are defined
along the x-axis over which the gas velocity and void fraction is both time-
and depth-averaged.  

## Additional Remarks

None.

## Literature

[^1]: Ziegenhein, T. and Lucas, D. 2019. The critical bubble diameter of the
      lift force in technical and environmental, buoyancy-driven bubbly flows.
      International Journal of Multiphase Flow, 116, pp. 26-38.

[^2]: Lucas, D. and Ziegenhein, T. 2019. Influence of the bubble size
      distribution on the bubble column flow regime. International Journal of
      Multiphase Flow, 120.
