#! /usr/bin/env python3
#-------------------------------*- python -*-----------------------------------
# ==  == ====== ====   ====    |
#                   \\     ||  | Multiphase Cases Repository by HZDR
# ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.811
# ||  ||  //    ||  // || \\   | License: Creative Commons Attribution 4.0
# ==  == ====== ====   ==  ==  |
#------------------------------------------------------------------------------
# License
#     This file is part of the Multiphase Cases Repository by HZDR.
#
#     Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
#     Website: https://hzdr.de
#
#     The Multiphase Cases Repository by HZDR is licensed under the
#     Creative Commons Attribution 4.0 International License. To view a copy of
#     this license, visit http://creativecommons.org/licenses/by/4.0/ or send a
#     letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
#
#------------------------------------------------------------------------------

""" Calculate average in depth direction """

import csv
import os

TIME = (os.popen("foamListTimes -latestTime -case ..").read()).strip()

header = ['x', 'alphaMean.bubbles']
x_data = ['0.005625', '0.016875', '0.028125', '0.039375', '0.050625',
          '0.061875', '0.073125', '0.084375', '0.095625', '0.106875']

source = '../postProcessing'

alpha_data = []
x_alpha = []
for x in range(1,11):
    for root, dirs, filenames in os.walk(source):
        for directory in dirs:
            if directory=="H3_cell"+str(x)+".average":
                with open(source+"/"+directory+"/0/volFieldValue.dat",
                          encoding="utf-8") as f:
                    f.readline()
                    for line in f:
                        if line.startswith(TIME):
                            data = line.split()
                            alpha_data.append(data[1])

x_alpha = list(zip(x_data, alpha_data))

result_dir = "../postProcessing/python"
if not os.path.exists(result_dir):
    os.mkdir(result_dir)
result_dir += "/" + TIME
if not os.path.exists(result_dir):
    os.mkdir(result_dir)

file_out = f"{result_dir}/H3-depthAvg_alphaMean.bubbles.csv"

with open(file_out, 'w', encoding="utf-8") as f:
    csv_writer = csv.writer(f, delimiter=' ')
    csv_writer.writerow(header)
    csv_writer.writerows(x_alpha)


header2 = ['x', 'UMean.bubbles_x', 'UMean.bubbles_y', 'UMean.bubbles_z']

ugas_data = []
x_ugas = []
for x in range(1,11):
    for root, dirs, filenames in os.walk(source):
        for directory in dirs:
            if directory=="H3_cell"+str(x)+".average":
                with open(source+"/"+directory+"/0/volFieldValue.dat",
                          encoding="utf-8") as f:
                    f.readline()
                    for line in f:
                        if line.startswith(TIME):
                            line = line.replace(")", "").replace("(", "")
                            data = line.split()
                            ugas_data.append(data[2:])

x_ugas = [(k, l[0], l[1], l[2]) for k, l in zip(x_data, ugas_data)]

file_out = f"{result_dir}/H3-depthAvg_UMean.bubbles.csv"

with open(file_out, 'w', encoding="utf-8") as f:
    csv_writer = csv.writer(f, delimiter=' ')
    csv_writer.writerow(header2)
    csv_writer.writerows(x_ugas)
