# Simulation of Zaehringer (2020) [^1]

Bubble column cases have been simulated using OpenFOAM, with baseline
models developed by HZDR considering all the interfacial forces involved
in bubbly flow. For validation of the models results have been compared
with experimental data obtained from Magdeburg university.

The selected cases, ranging from S11 to L25, are monodisperse. These cases
are aptly named to convey crucial details: the initial letter designates the
nozzle size (S for small, M for medium, or L for large), the first digit
indicates the gas flow rate (ranging from 1 for low to 3 for high), and the
final digit denotes the liquid flow rate (ranging from 1 for low to 5 for high).

## The experiment

### Technical Information

The laboratory-scale bubble column in the experiment comprises a
rectangular cross section of 100 x 100mm^2  and a height of 2000mm.
The experiments are performed by using air and water at atmospheric
pressure and a temperature of 20°C. Air enters the column through a
gas distributor consisting of 7 nozzles with flow rates of 6 and 29l/hr.
The nozzles are interchangeable and have an inner diameter in the range
of 0.13 to 3.6mm, which produces bubbles of different diameter in the
range of 1.5 to 7mm. Liquid enters the column from the top, i.e.
as counter current flow, with a flow rate in the range of 0.6 to 55.5l/min or
Re= 100 to 9000. The water used during the experiment is clean.

The case properties are listed in a table below:

| Cases | dN_i [mm] | m_G [g/h] | J_G [m/s] | J_L [m/s] | d_B [m]  |
|:-----:|:---------:|:---------:|:---------:|:---------:|:--------:|
|  S11  |   0.13    |    2.4    | 5.56e-05  | 1.00e-03  | 1.41e-03 |
|  S12  |   0.13    |    2.4    | 5.56e-05  | 5.17e-03  | 1.46e-03 |
|  S13  |   0.13    |    2.4    | 5.56e-05  | 1.85e-02  | 1.41e-03 |
|  S14  |   0.13    |    2.4    | 5.56e-05  | 5.13e-02  | 1.48e-03 |
|  S15  |   0.13    |    2.4    | 5.56e-05  | 9.25e-02  | 1.54e-03 |
|  S21  |   0.13    |    7.1    | 1.70e-04  | 1.00e-03  | 2.25e-03 |
|  S22  |   0.13    |    7.1    | 1.70e-04  | 5.17e-03  | 2.27e-03 |
|  S23  |   0.13    |    7.1    | 1.70e-04  | 1.85e-02  | 2.24e-03 |
|  S24  |   0.13    |    7.1    | 1.70e-04  | 5.13e-02  | 2.31e-03 |
|  S25  |   0.13    |    7.1    | 1.70e-04  | 9.25e-02  | 2.44e-03 |
|  S31  |   0.13    |   11.9    | 2.80e-04  | 1.00e-03  | 2.69e-03 |
|  S32  |   0.13    |   11.9    | 2.80e-04  | 5.17e-03  | 2.71e-03 |
|  S33  |   0.13    |   11.9    | 2.80e-04  | 1.85e-02  | 2.70e-03 |
|  S34  |   0.13    |   11.9    | 2.80e-04  | 5.13e-02  | 2.77e-03 |
|  S35  |   0.13    |   11.9    | 2.80e-04  | 9.25e-02  | 2.91e-03 |
|  M11  |   0.18    |    2.4    | 5.56e-05  | 1.00e-03  | 3.26e-03 |
|  M12  |   0.18    |    2.4    | 5.56e-05  | 5.17e-03  | 3.38e-03 |
|  M13  |   0.18    |    2.4    | 5.56e-05  | 1.85e-02  | 3.35e-03 |
|  M14  |   0.18    |    2.4    | 5.56e-05  | 5.13e-02  | 3.45e-03 |
|  M15  |   0.18    |    2.4    | 5.56e-05  | 9.25e-02  | 3.50e-03 |
|  M21  |   0.18    |    7.1    | 1.70e-04  | 1.00e-03  | 3.40e-03 |
|  M22  |   0.18    |    7.1    | 1.70e-04  | 5.17e-03  | 3.52e-03 |
|  M23  |   0.18    |    7.1    | 1.70e-04  | 1.85e-02  | 3.48e-03 |
|  M24  |   0.18    |    7.1    | 1.70e-04  | 5.13e-02  | 3.60e-03 |
|  M25  |   0.18    |    7.1    | 1.70e-04  | 9.25e-02  | 3.55e-03 |
|  M31  |   0.18    |   11.9    | 2.80e-04  | 1.00e-03  | 3.47e-03 |
|  M32  |   0.18    |   11.9    | 2.80e-04  | 5.17e-03  | 3.60e-03 |
|  M33  |   0.18    |   11.9    | 2.80e-04  | 1.85e-02  | 3.54e-03 |
|  M34  |   0.18    |   11.9    | 2.80e-04  | 5.13e-02  | 3.66e-03 |
|  M35  |   0.18    |   11.9    | 2.80e-04  | 9.25e-02  | 3.75e-03 |
|  L11  |   3.60    |   11.5    | 2.70e-04  | 1.00e-03  | 6.00e-03 |
|  L12  |   3.60    |   11.5    | 2.70e-04  | 5.17e-03  | 6.00e-03 |
|  L13  |   3.60    |   11.5    | 2.70e-04  | 1.85e-02  | 6.85e-03 |
|  L14  |   3.60    |   11.5    | 2.70e-04  | 5.13e-02  | 6.00e-03 |
|  L15  |   3.60    |   11.5    | 2.70e-04  | 9.25e-02  | 6.00e-03 |
|  L21  |   3.60    |   34.5    | 8.00e-04  | 1.00e-03  | 6.42e-03 |
|  L22  |   3.60    |   34.5    | 8.00e-04  | 5.17e-03  | 6.50e-03 |
|  L23  |   3.60    |   34.5    | 8.00e-04  | 1.85e-02  | 6.50e-03 |
|  L24  |   3.60    |   34.5    | 8.00e-04  | 5.13e-02  | 6.53e-03 |
|  L25  |   3.60    |   34.5    | 8.00e-04  | 9.25e-02  | 6.55e-03 |
|  L31  |   3.60    |   57.5    | 1.34e-03  | 1.00e-03  | 6.88e-03 |
|  L32  |   3.60    |   57.5    | 1.34e-03  | 5.17e-03  | 6.88e-03 |
|  L33  |   3.60    |   57.5    | 1.34e-03  | 1.85e-02  | 6.86e-03 |
|  L34  |   3.60    |   57.5    | 1.34e-03  | 5.13e-02  | 6.86e-03 |
|  L35  |   3.60    |   57.5    | 1.34e-03  | 9.25e-02  | 6.60e-03 |

dN_i - inner nozzle diameter in experiment
m_G  - air massflow rate in experiment

### Data measured

Two different methods were employed to characterize gas and liquid flow
in the bubble column, measuring gas void fraction, as well as gas and
liquid phase velocities. Further details can be found in the literature [^1].
Depth-averaged gas void fraction, gas and liquid velocity profiles in the
lateral dimension were obtained, as well as axial liquid velocity profiles
from the centre of the column.

## The simulation setup

The case setups include the experimental data, as well as the reference
solution for three selected cases S25, M25 and L25.

To generate plots and run simulations, the Allrun script is
executed within the case folder, which then compares the calculated
results with the experimental data and the baseline model solution.

### Pre-Processing

The simulations are performed on a fully three-dimensional rectangular
domain. The imposed boundary conditions for the counter current flow
used in the simulations are well defined in Khan and Rzehak (2023) [^2].
The gas is injected via 7 mass source points.

### Post-Processing

The investigated area is 0.5m above the nozzles supplying the gas,
extended by the 0.535m inlet and 0.965m outlet sections. Results are
time-averaged starting from 250s up to end of the simulation time. The
results for the gas velocity and void fraction are depth-averaged in
order to mimic the experimental measuring technique by using
graphLayerAverage. Liquid velocities are plotted in the lateral dimension at a
measurement height and also vertically in the centre of the bubble column.
The scaled lateral and vertical coordinate x/D and z/L respectively is
used throughout.

## Additional Remarks

* Constant diameterModel
* Constant physical properties corresponding to T=20°C and p=1atm
* Superficial velocities J_G and J_L are provided from the experiments
* 5% turbulence intensity is prescribed at the inlet
* $`\omega`$ at the inlet is calculated using
  $`\omega = \frac {k^{0.5}} {C_\mu\space L_t}`$ with $`L_t = 0.2 R_H`$
  and $`C_\mu=0.09`$, where R_H is the hydraulic radius

## Literature

[^1]: Khan, H., Kováts, P., Zähringer, K., & Rzehak, R. (2024). Experimental
and numerical investigation of a counter current flow column.
Chemical Engineering Science 285, 119503.

[^2]: Khan, H., Lehnigk, R., & Rzehak, R. (2023). Euler-Euler simulation
of absorption and desorption in co- and counter-current bubble column
flows. Chemical Engineering Science 267, 118313.
