# Simulation of Sommer et al. (2023)

This is a templated simulation setup for the bubble column experiment by
Sommer et al. (2023)[^1]. It corresponds to the cases mentioned in Table 1 of
the paper. However, it should be noted that the table in the paper is erroneous,
and the correction is given below. The simulation results are compared to
the available experimental data, which can be found in Fig. 8 and 9 in the
paper. The Baseline model set developed at HZDR is used.

## The experiment

### Technical information

The bubble column is rectangular with a width of $0.1m$ and a depth of $0.05m$.
The ungassed liquid height is $0.5m$. The gas is introduced at the bottom of
the column through 14 needles arranged in a symmetrical way. Two different
needle diameters $d_i$ are used to influence the bubble size without changing
the gas flux.

No information is provided about the pressure and temperature, hence Standard
Ambient Temperature and Pressure conditions are assumed.

### Data measurements

The upward liquid velocity was measured using PIV, while the gas velocity, void
fraction and bubble size were measured using Shadowgraphy, and the data were
averaged over the depth of field.
The measurements were conducted at various heights of the column, but only the
data at the measurement height $z/H = 0.8$ are included here.

## The simulation setup

For a shorter computation time, only half of the bubble column is simulated
using a symmetry boundary condition at the column center. The dimension of the
simulated domain is therefore $0.05 \times 0.05 \times 0.5$ [m]. A unifrom mesh
is used with a cell size of $1.5 \times 1.5 \times 5$ [mm].

The different needle diameters are accounted for by choosing the case
corresponding bubble size.

### Case parameters

| Name | $J_G$ [m/s] | $d_B$ [mm] | $d_i$ [mm] |
|:----:|:-----------:|:----------:|:----------:|
|  T1  |    0.002    |    2.52    |    0.2     |
|  T2  |    0.002    |    3.66    |    0.6     |
|  T3  |    0.004    |    2.69    |    0.2     |
|  T4  |    0.004    |    3.89    |    0.6     |
|  T5  |    0.006    |    2.45    |    0.2     |
|  T6  |    0.006    |    4.47    |    0.6     |

## Pre-Processing

Mass source points are used to simulate the gas injection needles. The mass flow
rate per needle is calculated as

```math
mFR = J_G \times 0.1 \times 0.05 \times \rho_G/14.
```

Since two needles in the center intersect with the symmetry plane, their
corresponding mass source points produce together as much gas mass as one needle
$mFR1 = mFR$, while the other six mass source points produce together the same
gas mass as six needles $mFR2 = 6\times mFR$.

Degassing fvModel is used allowing the gas to leave the domain at the outlet.

The turbulent initial values are:

```math
k_{water} = \frac{3}{2} (I\,U_{inlet})^2 \quad\text{and}\quad
\omega_{water} \approx 10^5 \,k_{water} \\
\quad\text{resulting from}
\quad I=0.05 \quad\text{,}\quad
\omega_{water} = \frac{\rho_{water}}{\mu_{t}} \,k \quad\text{,}\quad
\frac{\mu_{t}}{\mu_{mol}} = 10 \quad\text{,}\quad U_{inlet}=0.05\\
\text{(SI units assumed)}\\
```

## Post-Processing

Results are time-averaged starting from $5$s to $30$s simulation time. Liquid
velocities are plotted using line plots. The results for the gas velocity and
void fraction are depth-averaged in order to mimic the experimental measuring
technique. A cell zone is defined along the x-axis over which the gas velocity
and void fraction is depth-averaged using `graphLayerAverage`.

## Additional Remarks

* Tomiyama et al. (1998) drag model for pure or slightly contaminated water
significantly improves the results

## Literature

[^1]: Sommer, A.-E., Draw, M., Wang, L., Schmidtpeter, J., Hessenkemper, H.,
      Gatter, J., Nam, H., Eckert, K., & Rzehak, R. (2023). Hydrodynamics in a
      bubble column - part 1: Two-phase flow. Chemical Engineering & Technology.
