# Simulation of Parthasarathy and Faeth (1987)

## Description

Cases simulating a submerged single-phase and multiphase (solid-liquid)
turbulent jet in a water tank are set-up with the models developed at
HZDR. These models are validated with the experiments from Parthasarathy
and Faeth [^1], Parthasarathy [^2]. The interfacial closure models used
for the glass bead particles are listed in the following table:

|    Particle model    |       Name       |
|:--------------------:|:----------------:|
|         Drag         | SchillerNaumann  |
|     Virtual mass     | $`C_{VM} = 0.5`$ |
|         Lift         |    ShiRzehak     |
|         Wall         |        -         |
| Turbulent dispersion |    ShiRzehak     |
|  Induced turbulence  |        -         |

Turbulence is only considered for the liquid phase and modeled
using the `kOmegaSST`turbulence model.

## Technical Information

A submerged single-phase as well as a particulate (solid-liquid) jet is
injected into a quiescent zone inside a rectangular cuboid water tank.
A premixed mixture of glass-water passes through an injector pipe and
later through a round nozzle of $`5.08 mm`$ in diameter and oriented
in the vertically downward direction with a uniform fixed value inlet velocity
and gas fraction. A constant monodisperse particle size of $`d_P=0.5 \space mm`$
is used. Water properties are assumed at SATP. A total
of 3 cases, i.e. a single-phase and two multiphase cases are
simulated for further validation.

The cases properties are listed in the following table:

|     Case     | $`U_S \space m/s`$ | $`vol_S \%`$ |
|:------------:|:------------------:|:------------:|
| singlePhase  |      $`1.61`$      |    $`0`$     |
| multiphase_1 |      $`1.66`$      |  $`0.024`$   |
| multiphase_2 |      $`1.72`$      |  $`0.048`$   |

## Pre-Processing

A cylindrical truncated domain around the nozzle was considered for
the simulation. The geometry was simplified to a wedge with an angle
of $`1.0`$ degree. For the single-phase simulation a multiphase solver
was used imposing a disperse phase fraction close to zero.

## Post-Processing

Validation data are available for the centreline streamwise velocities of
solid and liquid, radial profiles of mean streamwise velocities of
solid and liquid, turbulent kinetic energy and gas fractions
at three vertical positions.

### Data Validation

#### Centreline Profile

|  Field  |        Validation         | Reference |
|:-------:|:-------------------------:|:---------:|
|   U_L   | centerline_velocity_L.dat | line.csv  |
|   U_S   | centerline_velocity_S.dat | line.csv  |
| alpha_S |  centerline_alpha_S.dat   | line.csv  |

### Radial Profile at x = 8D

|  Field  | Validation  | Reference |
|:-------:|:-----------:|:---------:|
|   U_L   |   U_L.dat   | line.csv  |
|    k    |    k.dat    | line.csv  |
|   U_S   |   U_S.dat   | line.csv  |
| alpha_S | alpha_S.dat | line.csv  |

### Radial Profile at x = 16D

|  Field  | Validation  | Reference |
|:-------:|:-----------:|:---------:|
|   U_L   |   U_L.dat   | line.csv  |
|    k    |    k.dat    | line.csv  |
|   U_S   |   U_S.dat   | line.csv  |
| alpha_S | alpha_S.dat | line.csv  |

### Radial Profile at x = 40D

|  Field  | Validation  | Reference |
|:-------:|:-----------:|:---------:|
|   U_L   |   U_L.dat   | line.csv  |
|    k    |    k.dat    | line.csv  |
|   U_S   |   U_S.dat   | line.csv  |
| alpha_S | alpha_S.dat | line.csv  |

## Additional Remarks

The following is prescriptions by Rzehak and Kriebitzsch [^3]  are used to
define the inlet boundary conditions. These are as follows:

- Relative velocity at the inlet is zero,
i.e. $`\alpha_S =J_S/(J_S+J_L)`$, and $`U_S=U_L=J_S+J_L`$
- $`I = 5\%`$ turbulence intensity is prescribed at the inlet
- Turbulent kinetic energy is calculated as:
$`k = \frac{3}{2} {(I\space u_L)}^2`$
- $`\omega`$ at the inlet is calculated using
$`\omega = \frac {k^{0.5}} {C_\mu \space L_t}`$ with $`L_t=0.1D`$ and
$`C_\mu=0.09`$
- Superficial velocities are termed as $`J_S`$ and $`J_L`$
- Mean phasic velocities are termed as $`U_S`$ and $`U_L`$

Note, that the influence of the changes in faceMomentum (commit 87a7d4e) is not
tested in this case. Potentially, cell momentum, i.e. `faceMomentum false;`, is
required to achieve pleasant result or to achieve a numerically stable solution
in the first place.

## Literature

[^1]: Parthasarathy, R-N., & Faeth,G.M. (1987). Structure of particle-laden
      turbulent water jets in still water. Int. J. Multiphase Flow Vol. 13,
      No. 5, pp. 699-716

[^2]: Parthasarathy, R-N. (1989). Homogenous dilute turbulent particle-laden
      water flows. PhD thesis.

[^3]: Rzehak, R., & Kriebitzsch, S. (2015).Multiphase CFD-simulation of bubbly
      pipe flow: A code comparison. Int. J. Multiphase Flow Vol. 68, pp. 135-152
