# Simulation of Alajbegovic et al. (1994)

## Description

This is a templated simulation setup for the solid-liquid vertical pipe flow
experiment by Alajbegovic et al. (1994)[^1]. It corresponds to the cases
mentioned in Table 3 for ceramic particles (here named H1-H3 in heavy folder)
and Table 4 for expanded polystyrene particles (here named L1-L3 in light
folder) of the paper. The simulation results are compared to the available
experimental data, which can be found in Fig. 12 and 14 for solid fraction,
Fig. 15 and 16 for solid and liquid velocities, and Fig. 18 and 20 for liquid
turbulent kinetic energy in the paper. The models for the particle forces and
induced turbulence are listed here:

|        Model         |       Name       |
|:--------------------:|:----------------:|
|         Drag         |    ShiRzehak     |
|     Virtual mass     | $`C_{VM} = 0.5`$ |
|         Lift         |    ShiRzehak     |
|         Wall         |       Shi        |
| Turbulent dispersion |    ShiRzehak     |
|  Induced turbulence  |       Sato       |

## Technical Information

The vertical pipe is round and has a diameter of $30.6 mm$. The distance between
the inlet and the test section is $2.2 m$. Two kinds of particles are used,
ceramic particles with a density of $2442.65 kg/m^3$ and diameter of $2.32 mm$,
and expanded polystyrene particles with a density of $31.9 kg/m^3$ and diameter
of $1.79 mm$. No information is provided about the pressure and temperature,
hence Standard Ambient Temperature and Pressure conditions are assumed.

### Case Parameters

| Name | $J_S$ [m/s] | $J_L$ [m/s] |
|:----:|:-----------:|:-----------:|
|  L1  |    0.022    |    1.441    |
|  L2  |    0.023    |    1.722    |
|  L3  |    0.031    |    2.222    |
|  H1  |    0.032    |    1.410    |
|  H2  |    0.045    |    1.888    |
|  H3  |    0.060    |    2.196    |

## Pre-Processing

* For simplification, an axi-symmetric geometry (2D-wedge of 1 degree) is used
* Atmospheric pressure is imposed at the outlet
* The turbulent initial values are:

```math
k_{water} = \frac{3}{2} (I\,U_{inlet})^2 \quad\text{and}\quad
\omega = \frac {k^{0.5}} {C_\mu^{0.25}\space L_t} \\
\quad\text{with}
\quad L_t=0.07D \quad\text{, and}\quad C_\mu=0.09 \\
\text{(SI units assumed)}\\
```

## Post-Processing

* Radial solid fraction profile at the height $z/H = 0.88$
* Radial profile of axial liquid and solid velocities at the height
$z/H = 0.88$
* Radial profile of liquid turbulent kinetic energy at the height $z/H = 0.88$

## Additional Remarks

* ShiRzehak lift model yields near-wall peaked profiles for both kinds of
particles. For the light particle cases (expanded polystyrene particles L1-L3),
this reduces the liquid shear rate resulting in a steady-state flow after 3 s
simulation time. For the heavy particle cases (ceramic particles H1-H3), it
increases the liquid shear rate causing instability in the flow. In the latter
case, field averaging is applied between 3 and 6 s simulation time

* `faceMomentum` improves the results for the light particle cases

## Literature

[^1]: Alajbegovic, A., Assad, A., Bonetto, F. & Lahey, R. T. (1994). Phase
      distribution and turbulence structure for solid/fluid upflow in a pipe.
      International Journal of Multiphase Flow 20, 453-479.
