# Simulation of Rampure (2003)

## Description

Gas-solid-liquid bubble column simulation of the bubble column experiment
from Rampure et al. (2003) [^1]. The models for bubble and particle
forces [^2] used are listed in the following tables:

|     Bubble model     |       Name       |
|:--------------------:|:----------------:|
|         Drag         | IshiiZuberSparse |
|     Virtual mass     | $`C_{VM} = 0.5`$ |
|         Lift         |     Tomiyama     |
|         Wall         |     Hosokawa     |
| Turbulent dispersion |      Burns       |
|  Induced turbulence  |      Rzehak      |

|    Particle model    |       Name       |
|:--------------------:|:----------------:|
|         Drag         | SchillerNaumann  |
|     Virtual mass     | $`C_{VM} = 0.5`$ |
|         Lift         |    ShiRzehak     |
|         Wall         |        -         |
| Turbulent dispersion |    ShiRzehak     |
|  Induced turbulence  |        -         |

Turbulence is considered only in the liquid phase and modeled using `kOmegaSST`
turbulence model and a bubble induced turbulence model.
A `phasePressure` model is used for the particle phase to maintain a maximum
packing limit $`\alpha_{max} = 0.62`$.

## Technical Information

The column diameter and height are $`D=0.2 \space m`$ and $`H=1 \space m`$,
respectively.

A constant monodisperse bubble and particle size is used with
$`d_B=7 \space mm`$, and $`d_P=450 \space \mu m`$, respectively.
The particle density is given as $`\rho_S=2400 \space  kg/m^3`$.
Air and water material properties are evaluated at SATP.

The cases properties are listed in the following table:

| Case | $`J_G \space m/s`$ | $`vol_S \%`$ |
|:----:|:------------------:|:------------:|
|  C1  |      $`0.05`$      |    $`0`$     |
|  C2  |      $`0.1`$       |    $`0`$     |
|  C3  |      $`0.2`$       |    $`0`$     |
|  S1  |      $`0.1`$       |    $`5`$     |
|  S2  |      $`0.2`$       |    $`5`$     |
|  S3  |      $`0.1`$       |    $`10`$    |
|  S4  |      $`0.1`$       |    $`20`$    |

## Pre-Processing

Due to significant velocity fluctuations, an axisymmetric wedge should not be
employed. Therefore, a 3D O-grid mesh is used to simulate the bubble column.

The entire area of `inlet` is operating as a uniform gas inlet. A degassing BC
is used at the `outlet` excluding the particle phase. A free slip wall is
applied for bubble and particle phases, and a no-slip wall for the liquid phase.

To determine $`\alpha_G`$ at the inlet, the liquid and gas-liquid relative
velocities are set to $`u_L=0`$ and $`u_{rel}=0.2 \space m/s`$, respectively.
Therefore, $`\alpha_G = J_G/u_{rel}`$.

Initial and inlet turbulence quantities are determined as follows (SI units
assumed):

```math
k = \frac{3}{2} (I\,U)^2\\
\omega = \frac{k}{\nu_{t}}\\
\nu_{t} = 10\,\nu\\
```

with $`U= 0.2 \space m/s`$ as the estimated mean water velocity next to the
inlet, and $`I = 0.05`$.

## Post-Processing

Validation data are available for void fraction on radial profiles, and
for solid fraction on axial and radial profiles.

### Data Validation

|       Field        | Validation | Reference |      Position $`[m]`$       |
|:------------------:|:----------:|:---------:|:---------------------------:|
|   alphaMean.air    | alpha.dat  | line.csv  |      $`z=0.155, 0.65`$      |
| alphaMean.particle | alpha.dat  | line.csv  | $`r=0`$ and $`z=0.35, 0.7`$ |

## Additional Remarks

- No bubble size measurement was performed by the experimentalists, but it was
rather estimated in the range $`[1 - 20] \space mm`$. For the simulation,
a bubble size study was performed (using the older version of baseline),
which determined that $`d_B = 7 \space mm`$ yields the most agreeable results
with the experiment data.

- An ideal monodisperse bubble size or more agreeable results with the
experimental data are not yet determined in the current baseline models due to
the long computation time.

- A `corrected` scheme is used for the surface normal gradient `snGradSchemes`
in addition to $`1`$ `nNonOrthogonalCorrectors` to correct for mesh
non-orthogonality, $`\alpha_{max}= 25°`$. Note that $`\alpha`$ here is the angle
between cell-cell vector and face normal vector.

## Literature

[^1]: Rampure, M.R., Buwa, V.V, & Ranade, V.V (2003). Modelling of
      Gas-Liquid/Gas-Liquid-Solid Flows in Bubble Columns: Experiments and CFD
      Simulations The Canadian Journal of Chemical Engineering Vol. 81,
      p. 692-706. <https://doi.org/10.1002/cjce.5450810348>

[^2]: Shi, P., & Rzehak, R. (2020). Solid-liquid flow in stirred tanks:
      Euler-Euler/RANS modeling. Chemical Engineering Science, 227,
      115875. <https://doi.org/10.1016/j.ces.2020.115875>
