# Simulation of Sommer et al. (202X)

This is a templated simulation setup for the gas-solid-liquid bubble column
experiment by the upcoming work of Sommer et al. (202X). The cases are listed
in the table below. The simulation results are compared to some of the already
available experimental data. The employed model set is detailed below.

## The experiment

### Technical information

The experimental setup is identical to the one published in Sommer et al. (2023)
[^1]., with the exception of including solid particles.

The bubble column is rectangular with a width of $0.1m$ and a depth of
$0.05m$. The ungassed liquid height is $0.5m$. The gas is introduced at the
bottom of the column through 14 needles arranged in a symmetrical way.
Two different needle diameters $d_i$ are used to influence the bubble size
without changing the gas flux.

PMMA particles of size $0.3025 mm$ and density $1020 kg/m^3$ are used with
varying concentrations.

No information is provided about the pressure and temperature, hence Standard
Ambient Temperature and Pressure conditions are assumed.

### Data measurements

The upward liquid and solid velocities, solid fraction were measured using PIV,
while the gas velocity, void fraction and bubble size were measured using
Shadowgraphy, and the data were averaged over the depth of field.

The measurements were conducted on radial positions at various heights of the
column, but only the data at the measurement height $z/H = 0.8$ are included
here.

The solid fraction was also measured over the height at $x/L = 0, y/D = 0$.

## The simulation setup

For a shorter computation time, only half of the bubble column is simulated
using a symmetry boundary condition at the column center. The dimension of the
simulated domain is therefore $0.05 \times 0.05 \times 0.5$ [m]. A unifrom mesh
is used with a cell size of $1.5 \times 1.5 \times 5$ [mm].

The different needle diameters are accounted for by choosing the case
corresponding bubble size.

### Case parameters

| Name | $J_G$ [m/s] | $\alpha_S$ [%] | $d_B$ [mm] | $d_i$ [mm] |
|:----:|:-----------:|:--------------:|:----------:|:----------:|
|  L1  |    0.002    |      0.05      |    2.71    |    0.2     |
|  L2  |    0.002    |      0.05      |    3.57    |    0.6     |
|  L3  |    0.002    |      0.10      |    2.70    |    0.2     |
|  L4  |    0.002    |      0.10      |    3.66    |    0.6     |
|  L5  |    0.002    |      0.15      |    2.65    |    0.2     |
|  L6  |    0.002    |      0.15      |    3.65    |    0.6     |
|  L7  |    0.004    |      0.05      |    2.56    |    0.2     |
|  L8  |    0.004    |      0.05      |    3.92    |    0.6     |
|  L9  |    0.004    |      0.10      |    2.53    |    0.2     |
| L10  |    0.004    |      0.10      |    3.98    |    0.6     |
| L11  |    0.004    |      0.15      |    2.53    |    0.2     |
| L12  |    0.004    |      0.15      |    4.05    |    0.6     |
| L13  |    0.006    |      0.05      |    2.47    |    0.2     |
| L14  |    0.006    |      0.05      |    4.40    |    0.6     |
| L15  |    0.006    |      0.10      |    2.45    |    0.2     |
| L16  |    0.006    |      0.10      |    4.47    |    0.6     |
| L17  |    0.006    |      0.15      |    2.56    |    0.2     |
| L18  |    0.006    |      0.15      |    4.49    |    0.6     |

## Pre-Processing

Mass source points are used to simulate the gas injection needles. The mass flow
rate per needle is calculated as

```math
mFR = J_G \times 0.1 \times 0.05 \times \rho_G/14.
```

Since two needles in the center intersect with the symmetry plane, their
corresponding mass source points produce together as much gas mass as one needle
$mFR1 = mFR$, while the other six mass source points produce together the same
gas mass as six needles $mFR2 = 6\times mFR$.

Degassing fvModel is used allowing the gas to leave the domain at the outlet.

The turbulent initial values are:

```math
k_{water} = \frac{3}{2} (I\,U_{inlet})^2 \quad\text{and}\quad
\omega_{water} \approx 10^5 \,k_{water} \\
\quad\text{resulting from}
\quad I=0.05 \quad\text{,}\quad
\omega_{water} = \frac{\rho_{water}}{\mu_{t}} \,k \quad\text{,}\quad
\frac{\mu_{t}}{\mu_{mol}} = 10 \quad\text{,}\quad U_{inlet}=0.05\\
\text{(SI units assumed)}\\
```

## Post-Processing

Results are time-averaged starting from $20$s to $30$s simulation time. Liquid
and solid velocities, and solid fraction are plotted using line plots.
The results for the gas velocity and void fraction are depth-averaged in order
to mimic the experimental measuring technique. A cell zone is defined along the
x-axis over which the gas velocity and void fraction is depth-averaged using
`graphLayerAverage`.

## Additional Remarks

* Tomiyama et al. (1998) drag model for pure or slightly contaminated water
significantly improves the results in comparison to Ishii & Zuber (1979) drag
model.

* Particle-induced turbulence shows no significant influence whether it is
modelled according to Rzehak & Krepper (2013) or Sato et al. (1981).

* Currently, the only available validation data are of the gas fraction and
velocity and only for cases with large injection needles
(even cases, such as L2, L4, L6, etc.).Once available, additional validation
data of the solid fraction and solid and liquid velocities will be added
potentially for all cases.

## Literature

[^1]: Sommer, A.-E., Draw, M., Wang, L., Schmidtpeter, J., Hessenkemper, H.,
      Gatter, J., Nam, H., Eckert, K., & Rzehak, R. (2023). Hydrodynamics in a
      bubble column - part 1: Two-phase flow. Chemical Engineering & Technology.
