# Simulation of Deckwer et al. (1978)

## Description

Cases for gas-liquid mass transfer in bubbly pipe flows have been set-up.
Mass transfer models are used in combination with fluid dynamic models,
developed at HZDR. The simulation results of cases (case16A and case16B) are
validated with the previous simulation results of Rzehak et al. (2016) [^2], and
also with the experimental work of Deckwer et al. (1978) [^1].

The three selected cases are as follows;

- case16A (homogeneous inlet, monodisperse)
- case16B (non-homogeneous inlet, monodisperse)
- case16C (homogeneous inlet, polydisperse)

## Technical Information

The absorption of gas into liquid has been carried out in a circular pipe having
a diameter D = 150 mm. The total length of the flow section is H = 4400 mm. CO2
is used as the transferred species, the bubbles are the mixtures of CO2 and
air, while the liquid is water. The flow is co-current. The material properties
for CO2, air and water are evaluated at 14 °C temperature and at ambient
pressure i.e. 1 bar.

For the monodisperse cases, an averaged value for the bubble size and an
experimentally determined value for the mass transfer coefficient has been used.
While, for the polydisperse case, the Brauer [^3] model has been used which
depends on the bubble size in order to calculate the mass transfer coefficient.

The cases include the experimental data, old simulation [^2] (CFX results) as
well as the reference solution. The simulations are run and plots are generated
by executing the Allrun script inside the case folder, which compares the
computed results to the experimental data.

## Pre-Processing

In order to simplify the experimental setup for simulations, an axis-symmetric
geometry (2D-wedge of 1.0 deg.) for replicating the actual flow is simulated.
Two different inlet flow conditions are used. Homogeneous and non-homogeneous
inlet. The condition in which gas and liquid enters through the same inlet
called Homogeneous inlet, while the condition where both phases enters through
the separate inlet is defined as non-homogeneous inlet.

## Post-Processing

Cross-sectionally averaged values are extracted by using `graphLayerAverage`.
The extracted values are axially plotted in order to make comparison with the
measured values. The scaled vertical coordinate y/H is used throughout.

### Data Validation

|    Field    |            Validation            |
|:-----------:|:--------------------------------:|
|  alpha.gas  | alphaGExp16.dat, alphaGCFX16.dat |
|  YCO2.gas   |     YGExp16.dat, YGCFX16.dat     |
| YCO2.liquid |           YLCFX16.dat            |

## Keywords

pipe, circular-cross-section, vertical-upward, co-current, air-CO2-water,
bubbly-flow, multicomponent, fixed-bubble-size, monodisperse, polydisperse,
isothermal, 2D-wedge, mass transfer, pressure-outlet, homogeneous inlet,
non-homogeneous inlet, mass transfer coefficient

## Additional Remarks

Note, that the influence of the changes in faceMomentum (commit 87a7d4e) is not
tested in this case. Potentially, cell momentum, i.e. `faceMomentum false;`, is
required to achieve pleasant result or to achieve a numerically stable solution
in the first place.

## Literature

[^1]: Deckwer, W.-D., Adler, I. and Zaidi, A., 1978. A comprehensive study on
CO2-interphase mass transfer in vertical co-current and countercurrent gas-liquid
flow. Canadian Journal of Chemical Engineering 56, 43–55.

[^2]: Rzehak, R., Krepper, E., 2016. Euler-Euler simulation of mass-transfer in
bubbly flows. Chemical Engineering Science 155, 459–568.

[^3]: Brauer, H., 1981. Mass transfer operations between liquid films and
adjoining gas streams. Progress in Chemical Engineering 19, 81–111.
