# Simulation of Akhtar et al. (1991)

## Description

This case simulates the formation of titania powder in a laboratory scale
aerosol reactor[^1]. The core part of the experiment is an externally heated
alumina pipe with an inner diameter of 31.8mm and a length of 1.5m.
Inside the reactor, titanium tetrachloride vapour reacts with oxygen to form
solid titania particles, which then grow by aggregation up to a size of one
micrometer, with chlorine as a by-product of the reaction. The reactants are
diluted by argon gas. The reactor effluents are cooled by a dilution system at
the end of the pipe consisting of two concentric tubes. Through the annular gap
between both tubes, cool nitrogen is introduced into the reactor and quenches
further aggregation. A complete description of the computational setup is
available from the PhD thesis of Lehnigk[^2].

## Technical Information

* 2D wedge
* 296K gas temperature at reactor and dilutor inlet
* Measured temperature profile is applied at the reactor wall
* 2.82l/min argon at the inlet
* 0.056l/min oxygen at the inlet
* 7.38e-5mol/l titanium tetrachloride at the inlet (1.56e-5mol/L at 1400K)
* 5l/min nitrogen at dilutor inlet
* Application of population balance modeling
* Reaction driven nucleation and fractal aggregation

## Pre-Processing

* Base geometry is a pipe created with the blockMesh utility
* Inlet and dilutor regions are added with topoSet/createPatch/extrudeMesh

## Post-Processing

* graphCell (temperature and species)
* sizeDistribution
* residuals
* layerAverage for computing cross-sectional averages
* gnuplot script to plot axial temperature and species mass fraction profiles
* Measured wall temperature and size distribution in validation directory

## Keywords

## Additional Remarks

## Literature

[^1]: Akhtar, M. K., Xiong, Y., & Pratsinis, S. E. (1991).
    Vapour synthesis of titania powder by titanium tetrachloride oxidation.
    AIChE Journal, 37(10), 1561-1570.

[^2]: Lehnigk, R. (2021).
    A generalized population balance model for the simulation of polydisperse
    multiphase flows within the Euler-Euler framework.
    PhD thesis, TU Dresden, Germany.
