#! /usr/bin/env python3
#-------------------------------*- python -*-----------------------------------
# ==  == ====== ====   ====    |
#                   \\     ||  | Multiphase Cases Repository by HZDR
# ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.811
# ||  ||  //    ||  // || \\   | License: Creative Commons Attribution 4.0
# ==  == ====== ====   ==  ==  |
#------------------------------------------------------------------------------
# License
#     This file is part of the Multiphase Cases Repository by HZDR.
#
#     Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
#     Website: https://hzdr.de
#
#     The Multiphase Cases Repository by HZDR is licensed under the
#     Creative Commons Attribution 4.0 International License. To view a copy of
#     this license, visit http://creativecommons.org/licenses/by/4.0/ or send a
#     letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
#
#------------------------------------------------------------------------------

""" Create a CSV file """

import numpy as np

## scaling keeping aspect ratio
# set target size in x direction and y_max
inputfile  = 'C1_shape_OpenFOAM_t3.0_extracted_from_paper.dat'
outputfile = 'C1_shape_OpenFOAM_t3.0_xyz.csv'

target_xmin   = 0.21
target_xmax   = 0.79
target_ymax   = 1.63
zconst        = 0.51 # to write 3D points

# read coordinates
data = np.loadtxt(inputfile)
x = data[:,0]
y = data[:,1]

# scale
xcentre = np.mean(x)
ycentre = np.mean(y)

xloc = x - xcentre
yloc = y - ycentre

scale  = ( target_xmax - target_xmin )/( np.max(xloc)-np.min(xloc) )

xnew = xcentre + scale*xloc
ynew = ycentre + scale*yloc

# shift
xnew = xnew - np.max(xnew) + target_xmax
ynew = ynew - np.max(ynew) + target_ymax

# add z coordinate
znew = np.ones(np.size(xnew)) * zconst

# save to file
np.savetxt(outputfile,np.c_[xnew,ynew,znew],delimiter=',',header='x,y,z')
print(outputfile + " written.")
