# Simulation of Single Rising Bubble of Balcazar et al. (2015)

## Description

A single bubble with different Eötvös and Morton numbers is investigated. The
reference solution is provided by Balcázar et al. (2015)[^1] with a level-set
method.

This case is intended to serve as reference for the resolved capabilities of
the cipsaMultiphaseEuler solver. For cases Eo=116 and 339, the results are
reported by Meller et al. (2021)[^2], section 4.3.

The subdirectories contain setups for different mesh resolutions based on the
number of cells per bubble diameter.

## Technical Information

Naming convention for directories is bound to the Eötvös number.
Each case includes a blockMeshDict for 4, 8, 16 and 32 cells per diameter.
The CFL number should stay around 0.1.

## Pre-Processing

A spherical bubble is initialised with setFields.

## Post-Processing

FunctionObjects used at run time:

* residuals
* probes
* vLine (sampleDict: graph)
* surfaces
* bubbleSurfaces (surfaces: isosurface)
* bubble (phaseStructureProperties)

Bash script:

* Gnuplot script createGraphs

## Reference Values

| Eötvös No. | Morton No. | Reynolds No. | Note                   |
|------------|------------|--------------|------------------------|
| 10         | 0.001      | 24           | Clift (1978)           |
| 116        | 41.1       | 6.94         | Balcázar et al. (2015) |
| 339        | 43.1       | 17.46        | Balcázar et al. (2015) |

## Keywords

multimorph, single bubble

## Literature

[^1]: Balcázar, N., Lehmkuhl, O., Jofre, L., Oliva, A. (2015).
      Level-set simulations of buoyancy-driven motion of single and multiple
      bubbles.
      International Journal of Heat and Fluid Flow, 56, 91–107.

[^2]: Meller, R., Schlegel, F., Lucas, D. (2021).
      Basic verification of a numerical framework applied to a morphology
      adaptive multifield two-fluid model considering bubble motions.
      International Journal for Numerical Methods in Fluids, 93(3), 748-773.
