# Simulation of a Column Tray of a Distillation Column

## Description

This test case describes the column tray experiment with a single valve carried
out by Wiedemann et al. (2023)[^1]. The chosen working point is MP_06.

It features continuous and disperse phases for both gas (air) and liquid
(water). Continuous gas is injected into the domain via volume sources at the
location of the valve with a sine form function for temporal evolution to mimic
the valve behaviour in the experiment. Morphology transfer between the numerical
representations are modelled by disintegrationToDisperse and
accumulationToContinuous phaseTransfer models. Bubbles and droplets are
described as monodisperse phases with fixed particle diameters.

## Technical Information

* 3D
* 138,120 mesh cells
* inlet of continuous water
* injection of continuous air in valve region via sine pulsed mass source
* turbulence damping for continuous gas phase

## Pre-Processing

* left and right sparger position via topoSet
* initial gas and liquid distributions via setFields

## Post-Processing

FunctionObjects used used at run time:

* residuals
* fieldAverage
* isoSurface

Bash script:

* Gnuplot script createGraphs

## Keywords

3D, multimorph, column tray, air-water, disintegration, accumulation,
phase-transfer, monodisperse, fixed-bubble-size, bubbly-flow, droplet-flow,
large-interface, atmosphere, disperse-gas, disperse-liquid

## Literature

[^1]: Wiedemann, P., Meller, R., Schubert, M., & Hampel, U. (2023).
      Application of a hybrid multiphase CFD approach to the simulation of gas–
      liquid flow at a trapezoid fixed valve for distillation trays.
      Chemical Engineering Research and Design, 193, 777–786.
