# Simulation of Plunging Jet Case of Chanson et al. (2004)

## Description

This case features the geometry of Chanson's plunging jet experimental setup
[^1]. A jet of water is entering the domain from the top, plunging into a basin
of stagnant water. A matching BC at the bottom removes water at the same rate as
injected at the inlet in order to maintain the total volume of water in the
domain. Castro's correlation[^2] is used to model the unresolved entrainment.
Additionally, large gas structures might breakup into dispersed gas bubbles,
which is described via the *disintegrationToDisperse* morphology transfer model
[^3]. Finally, the disperse air phase is transformed back to continuous air,
when it reaches the water surface, which is described by the
*accumulationToContinuous* phase transfer model[^4]. The disperse air phase is
modelled monodisperse with a bubble diameter of D_b = 3.5 mm (average diameter
observed in experiments).

## Technical Information

* 3D
* three different grids available: ~5000 to ~250 000 cells
* height: 1.8 m
* radius: 0.3 m
* averaging: 5 s < t < 25 s
* multiMorph model
* upper limit for omega.air to ensure a minimum turbulent viscosity
* continuousBuoyancy - gravity term modification[^5]

## Pre-Processing

Initialisation of fields with the setFields utility.

## Post-Processing

* residuals
* Courant numbers for specific phases
* time averaging of gas fraction fields and of water velocity field
* water velocity extracted at vertical centre line
* air fraction profiles extracted at different horizontal at three different
  vertical positions
* volume integral of gas fractions over time
* plots produced via gnuplot script createGraphs
* monitor Courant number and results at run time via *./validation/monitorRun*

## Keywords

3D, plunging-jet, isothermal, incompressible, air-water, entrainment,
accumulation, disintegration, phase-transfer, top-inlet, vertical-downward,
stagnant-water, monodispersed, fixed-bubble-size, bubbly-flow,
single-phase-inlet, atmosphere

## Literature

[^1]: Chanson, H., Aoki, S. I., & Hoque, A. (2004).
      Physical modelling and similitude of air bubble entrainment at vertical
      circular plunging jets.
      Chemical engineering science, 59(4), 747-758.

[^2]: Castro, A. M., Li, J., & Carrica, P. M. (2016).
      A mechanistic model of bubble entrainment in turbulent free surface flows.
      International Journal of Multiphase Flow, 86, 35–55.

[^3]: Meller, R., Krull, B., Schlegel, F., & Tekavčič, M. (2023).
      Numerical Transfer Towards Unresolved Morphology Representation in the
      MultiMorph Model.
      The 20th International Topical Meeting on Nuclear Reactor Thermal
      Hydraulics (NURETH-20), 1–14.

[^4]: Schlegel, F., Meller, R., Krull, B., Lehnigk, R., & Tekavčič, M. (2022).
      OpenFOAM-Hybrid: A Morphology Adaptive Multifield Two-Fluid Model.
      Nuclear Science and Engineering, 0(0), 1–14.

[^5]: Meller, R., Tekavčič, M., Krull, B., & Schlegel, F. (2023).
      Momentum exchange modeling for coarsely resolved interfaces in a
      multifield two‐fluid model.
      International Journal for Numerical Methods in Fluids, 1–25.
