# Simulation of Single Rising Bubble of Hysing et al. (2009)

## Description

This test case refers to *Two-Dimensional Bubble Rising in Liquid with Micro
Gas Bubbles* of section 4.4 of Meller et al. (2021)[^1].

It features a single air bubble in a stagnant water column. This gas bubble
regime was proposed by Hysing et al. (2009)[^2] as a benchmark test case
(case 1). The domain is extended in vertical direction. After the beginning of
the simulation the large gas bubble passes a layer, which contains 10 % of
finely dispersed gas. Both gas phases have identical physical properties. The
intention of this case is to demonstrate the functionality of
cipsaMultiphaseEuler to treat a resolved interface in connection with
dispersed gas.

| Quantity    | Value |
|-------------|-------|
| rho_1       | 1000  |
| rho_2       | 100   |
| rho_d       | 100   |
| mu_1        | 10    |
| mu_2        | 1     |
| mu_d        | 1     |
| g           | 0.98  |
| sigma_12    | 24.5  |
| Re          | 35    |
| Eo          | 10    |
| rho_1/rho_2 | 10    |
| mu_1/mu_2   | 10    |
| D_b         | 0.5   |
| D_d         | 4e-2  |

## Technical Information

* 2D
* 64 000 mesh cells
* top and bottom: no-slip walls
* left and right: slip walls
* large gas bubble and
* baseline models for dispersed gas in liquid
* definite phases blending method

## Pre-Processing

* large gas bubble and micro bubbles initialised with setFields utility

## Post-Processing

FunctionObjects used at run time:

* residuals
* surfaces
* bubbleSurface (surfaces: isosurface)
* bubbleProperties (phaseStructureProperties)

Bash script:

* Gnuplot script createGraphs

## Keywords

multimorph, gas bubble, disperse gas

## Literature

[^1]: Meller, R., Schlegel, F., Lucas, D. (2021).
      Basic verification of a numerical framework applied to a morphology
      adaptive multifield two-fluid model considering bubble motions.
      International Journal for Numerical Methods in Fluids, 93(3), 748-773.

[^2]: Hysing, S.R., Turek, S., Kuzmin, D., Parolini, N., Burman, E.,
      Ganesan, S., Tobiska, L. (2009).
      Quantitative benchmark computations of two‐dimensional bubble dynamics.
      International Journal for Numerical Methods in Fluids, 60(11), 1259-1288.
