# Simulation of a Single Rising Bubble of Meller et al. (2022)

## Description

A single wobbling gas bubble is investigated rising in stagnant liquid. This
test case is proposed by Meller et al. (2022)[^1]. The case is intended to serve
for assessment of different closure models for the convective sub-grid stress
(LES model) with the multifield two-fluid model. The inlet velocity is
controlled to maintain the vertical bubble position. Thus, the gas bubble is
observed in it's own frame of reference, which allows for the collection of
long-time statistical data of interface-flow interaction.

| Quantity    | Value   |
|-------------|---------|
| rho_1       | 100     |
| rho_2       | 1       |
| mu_1        | 0.03    |
| mu_2        | 0.003   |
| g           | 0.00919 |
| sigma       | 0.367   |
| Re_g = Ga   | 320     |
| Eo          | 2.5     |
| Mo          | 1.5e-9  |
| rho_1/rho_2 | 100     |
| mu_1/mu_2   | 10      |

## Technical Information

* 3D
* 324 000 mesh cells
* top: liquid inflow
  * uniform velocity profile
  * value controlled by vertical bubble position via PID controller and
        bubbleProperties (phaseStructureProperties) functionObject
* bottom: liquid outflow
* side walls: pairwise periodic
* sub-grid stress model (LES):
    scale similarity model with Klein's regularization (KleinscaleSimilarity)

## Pre-Processing

The spherical bubble is initialised with setFields. Liquid and gas are at rest
initially.

## Post-Processing

FunctionObjects used at run time:

* inletVelocity (patchAverage):
    track inflow velocity
* surfaceCentre (surfaces):
    extract data from horizontal plane at the height of the bubble centre
* bubbleProperties (phaseStructureProperties)
    vertical bubble position
* trackBubble (trackPhaseStructures)
    for position, velocity and volume of individual gas structures, which might
    be created by separation of the gas bubble by the periodic boundary
    conditions at the sides of the domain
* several python3 scripts in validation/ used to process the data
    described above
* gnuplot script in validation/ to produce graphs
  * radialProfile_U.png corresponds to Fig. 4, 6 and 7 in the paper draft
  * 3Dtrajectory.png corresponds to Fig. 3 in the paper draft

## Keywords

multimorph, single bubble, frame of reference, LES

## Literature

[^1]: Meller, R., Schlegel, F., Klein, M. (2022).
      Sub-grid scale modelling and a-posteriori tests with a morphology adaptive
      multifield two-fluid model considering rising gas bubbles.
      Flow, Turbulence and Combustion 108, pp. 895-922.
