#! /usr/bin/env python3
#-------------------------------*- python -*-----------------------------------
# ==  == ====== ====   ====    |
#                   \\     ||  | Multiphase Cases Repository by HZDR
# ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.811
# ||  ||  //    ||  // || \\   | License: Creative Commons Attribution 4.0
# ==  == ====== ====   ==  ==  |
#------------------------------------------------------------------------------
# License
#     This file is part of the Multiphase Cases Repository by HZDR.
#
#     Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
#     Website: https://hzdr.de
#
#     The Multiphase Cases Repository by HZDR is licensed under the
#     Creative Commons Attribution 4.0 International License. To view a copy of
#     this license, visit http://creativecommons.org/licenses/by/4.0/ or send a
#     letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
#
#------------------------------------------------------------------------------

""" Draw heatmap from case study results """

import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns

# read data file
df = pd.read_csv('caseStudyResults.csv', sep=r'\s+')

# construct field from table (two columns as indices, one column as values)

title = r'Drag [N]'
values = 'drag'
# title = r'Continuous gas fraction $V_\mathrm{gas,c}\;[m^3]$'
# values = 'totalVolumeContinuousGas'

matrix = df.pivot(index='massFlowRate', columns='hullVelocity', values=values)

# absolute value
matrix = matrix.abs()

print(matrix)

# plot heatmap
plt.figure(figsize=(10, 10))
sns.set(font_scale=1.5)

maxval = matrix.max().max()
ax = sns.heatmap(matrix, cmap='crest', annot=True, fmt='.1e', vmax=maxval)

ax.invert_yaxis()
plt.title(title, fontsize=22)
plt.xlabel(r'Ship velocity $U\;[m/s]$', fontsize=22)
plt.ylabel(r'Gas flow rate $\dot{m}_\mathrm{gas}\;[kg/s]$', fontsize=22)

plt.show()
