# Simulation of WENKA Test Facility

## Description

Simulation (2D) set-up for WENKA test facility

The validation case MP3_23 considers isothermal supercritical counter-current
stratified flow in WENKA experiment with a Froude number of 2.36 and
Reynolds numbers of 12000 for water and 27000 for air (Stäbler, 2007)[^1].

The computational domain is based on ANSYS CFX simulations
by Höhne and Porombka (2018)[^2] and represents the rectangular test channel
of WENKA facility.

## Technical Information

* 2D
* 8000 mesh cells
* StrubeljTiselj drag formulation
* Partial elimination
* Interface compression
* Turbulence damping with addonInterfaceTurbulenceDamping fvModel
    (formulation of Tekavčič et al., 2021[^3])
  * Symmetric damping with delta = 7e-5 in both phases
  * No damping in water
* Interface indicator with interfaceIndicatorMethod: gradAlpha
* Field mapping at air and water inlets

## Pre-Processing

* setFields for air and water

## Post-Processing

FunctionObjects used at run time:

* residuals
* time
* probes
* fieldAverage
* verticalLine_235
* verticalLine_380
* verticalLine_235_Mean
* verticalLine_380_Mean

Bash script:

* Gnuplot script createGraphs

Find all result files in the validation directory.
Commented are instructions to plot the mean fields if desired.

## Keywords

multimorph, stratified flow, turbulence damping

## Additional Remarks

* Field averaging
  * After initial 10 s transient, fields are averaged for additional 10 s.
* Approximate run time on 4 nodes in defq on hemera is 2.2 hours.
  * For testing, set shorter runs with endTime 5 s (~30 minutes), disable avg.

## Literature

[^1]: Stäbler, T. D. (2007). Experimentelle Untersuchung und physikalische
Beschreibung der Schichtenströmung in horizontalen Kanälen. PhD Thesis.
<https://dx.doi.org/10.18419/opus-1724>

[^2]: Höhne, T., & Porombka, P. (2018). Modelling horizontal two-phase flows
using generalized models. Annals of Nuclear Energy, 111, 311-316.

[^3]: Tekavčič, M., Meller, R., & Schlegel, F. (2021).
Validation of a morphology adaptive multi-field two-fluid model considering
counter-current stratified flow with interfacial turbulence damping.
Nuclear Engineering and Design, 379, 111223.
